BEGIN TRANSACTION;
CREATE TABLE User (
	UserName VARCHAR(100) NOT NULL,
	Password VARCHAR(100) NOT NULL,
	primary key(UserName)
);
CREATE TABLE `ShopHasProduct` (
	`Shop`	INTEGER NOT NULL,
	`Product`	VARCHAR(100) NOT NULL,
	`Price`	REAL NOT NULL,
	PRIMARY KEY(Shop,Product),
	FOREIGN KEY(`Shop`) REFERENCES Shop ( ID ) ON DELETE CASCADE ON UPDATE CASCADE,
	FOREIGN KEY(`Product`) REFERENCES Product ( Name ) ON DELETE CASCADE ON UPDATE CASCADE
);
CREATE TABLE Shop (
	ID integer primary key autoincrement,
	Name VARCHAR(255) NOT NULL,
	Longitude decimal(25,22) NOT NULL,
	Latitude decimal(25,22) NOT NULL
);
CREATE TABLE `Schedule` (
	`ShopID`	integer,
	`SerializedSchedule`	BLOB NOT NULL,
	FOREIGN KEY(`ShopID`) REFERENCES Shop ( ID ) ON DELETE CASCADE ON UPDATE CASCADE
);
CREATE TABLE Product (
	Name VARCHAR(100) NOT NULL,
	Unit VARCHAR(10) NOT NULL,
	Proteins REAL,
	Lipids REAL,
	Carbohydrates Real,
	primary key(Name)
);
CREATE TABLE `GroceryListContainsProduct` (
	`ListOwner`	VARCHAR(100) NOT NULL,
	`ListName`	BLOB NOT NULL,
	`Product`	BLOB NOT NULL,
	`Quantity`	BLOB NOT NULL,
	PRIMARY KEY(ListOwner,ListName,Product),
	FOREIGN KEY(`ListOwner`,  `ListName`) REFERENCES GroceryList (ListOwner, ListName) ON DELETE CASCADE ON UPDATE CASCADE,
	FOREIGN KEY(`ListOwner`) REFERENCES User ( UserName ) ON DELETE CASCADE ON UPDATE CASCADE
--	FOREIGN KEY(`Product`) REFERENCES Product ( Name ) APPLICATION CHECKS THIS; ALLOWS US TO ENCRYPT DATA
);
CREATE TABLE `GroceryList` (
	`ListOwner`	VARCHAR(100) NOT NULL,
	`ListName`	BLOB NOT NULL,
	PRIMARY KEY(ListOwner,ListName),
	FOREIGN KEY(`ListOwner`) REFERENCES User ( UserName ) ON DELETE CASCADE ON UPDATE CASCADE
);

CREATE TABLE `RecipeContainsProduct` (
	`RecipeOwner`	VARCHAR(100) NOT NULL,
	`RecipeName`	BLOB NOT NULL,
	`Product`	    BLOB NOT NULL,
	`Quantity`	    BLOB NOT NULL,
	PRIMARY KEY(RecipeOwner, RecipeName, Product),
	FOREIGN KEY(`RecipeOwner`,  `RecipeName`) REFERENCES Recipe(RecipeOwner, RecipeName) ON DELETE CASCADE ON UPDATE CASCADE,
	FOREIGN KEY(`RecipeOwner`) REFERENCES User ( UserName ) ON DELETE CASCADE ON UPDATE CASCADE
--	FOREIGN KEY(`Product`) REFERENCES Product ( Name ) APPLICATION CHECKS THIS; ALLOWS US TO ENCRYPT DATA
);
CREATE TABLE `Recipe` (
	`RecipeOwner`	VARCHAR(100) NOT NULL,
	`RecipeName`	BLOB NOT NULL,
	`NumPeople`	    BLOB NOT NULL,
	`Instructions`  BLOB NOT NULL,
	PRIMARY KEY(RecipeOwner, RecipeName),
	FOREIGN KEY(`RecipeOwner`) REFERENCES User ( UserName ) ON DELETE CASCADE ON UPDATE CASCADE
);
CREATE TABLE `Key` (
	`UserName`	VARCHAR(100) NOT NULL,
	`PublicKey`	BLOB NOT NULL,
	`EncryptedAESKey`	BLOB NOT NULL,
	`Salt`	    BLOB NOT NULL,
	PRIMARY KEY(UserName),
	FOREIGN KEY(`UserName`) REFERENCES User ( UserName ) ON DELETE CASCADE ON UPDATE CASCADE
);


COMMIT;