package be.ac.ulb.infof307.g02.constants;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

public class ConstantsLoader {
    private static final String CONSTANTS_PROPERTIES_FILENAME = "constants.properties";

    /**
     * Loads all the constants in the constants.properties file and puts the values
     * in the Constants class, so that the rest of the application can use them.
     *
     * @param filename
     */
    private static void load(String filename) {
        try {
            InputStream stream = ConstantsLoader.class.getClassLoader().getResourceAsStream(filename);
            Properties properties = new Properties();
            properties.load(stream);
            read(properties);
        } catch (IOException | ClassCastException e) {
            // Will not happen

        }
    }

    public static void loadAllConstants() {
        load(CONSTANTS_PROPERTIES_FILENAME);
    }

    private static void read(Properties properties) {
        Constants.PRICE_PER_KM = Double.parseDouble(properties.getProperty("COST_PER_KM"));
        Constants.PRODUCTION_DATABASE_PATH = properties.getProperty("PRODUCTION_DATABASE_PATH");
        Constants.TEST_DATABASE_PATH = properties.getProperty("TEST_DATABASE_PATH");
        Constants.CSS_FILE_PATH = properties.getProperty("CSS_FILE_PATH");
        Constants.FXML_FOLDER_PATH = properties.getProperty("FXML_FOLDER_PATH");
        Constants.DEFAULT_LAT = Double.parseDouble(properties.getProperty("DEFAULT_LAT"));
        Constants.DEFAULT_LNG = Double.parseDouble(properties.getProperty("DEFAULT_LNG"));
        Constants.TWIG_PATH = properties.getProperty("TWIG_PATH");
        Constants.PROTEINS_CALORIES_PER_GRAM = Double.parseDouble(properties.getProperty("PROTEIN_CALORIES_PER_GRAM"));
        Constants.LIPIDS_CALORIES_PER_GRAM = Double.parseDouble(properties.getProperty("LIPID_CALORIES_PER_GRAM"));
        Constants.CARBOHYDRATE_CALORIES_PER_GRAM = Double.parseDouble(properties.getProperty("CARBOHYDRATE_CALORIES_PER_GRAM"));
        Constants.KEYSTORE_FILE_PATH = properties.getProperty("KEYSTORE_FILE_PATH");
        Constants.KEYSTORE_RESOURCE_PATH = properties.getProperty("KEYSTORE_RESOURCE_PATH");
    }
}