package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.views.HelpPage;
import be.ac.ulb.infof307.g02.views.ViewWithMenu;

/**
 * Base class inherited by all the controllers that can interact with a menu
 */
public abstract class ControllerWithMenu extends Controller {

    private final HelpPage helpPage;
    private ViewWithMenu viewWithMenu;

    public ControllerWithMenu() {
        this(HelpPage.MAP);
    }

    public ControllerWithMenu(HelpPage helpPage) {
        this.helpPage = helpPage;
    }

    /**
     * Logout
     */
    public void onLogout() {
        this.master.onLogout();
    }

    /**
     * Shows the map
     */
    public void onShowMap() {
        this.master.onShowMap();
    }

    /**
     * Shows the Edit profile view
     */
    public void onShowEditProfile() {
        this.master.onShowEditProfile();
    }

    /**
     * Shows all the grocery lists of the logged in user
     */
    public void onShowAllGroceryLists() {
        this.master.onShowAllGroceryLists();
    }

    /**
     * Shows all the recipes of the logged in user
     */
    public void onShowAllRecipes() {
        this.master.onShowAllRecipes();
    }

    /**
     * Shows the Help View
     */
    public void onShowHelp() {
        this.master.onShowHelp(this.helpPage);
    }

    /**
     * Whenever the help window is opened or closed the help button must be disabled or enabled accordingly.
     * That's the responsibility of this function.
     *
     * @param isHelpOpen boolean to know if the help is open.
     */
    @Override
    public void onHelpViewStatusChanged(boolean isHelpOpen) {
        if (isHelpOpen) {
            this.viewWithMenu.disableHelpButton();
        } else {
            this.viewWithMenu.enableHelpButton();
        }
    }

    /**
     * Sets a viewWithMenu as the displayed view
     *
     * @param viewWithMenu
     */
    public void setView(ViewWithMenu viewWithMenu) {
        this.viewWithMenu = viewWithMenu;
    }


}

