package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.views.HelpPage;

/**
 * Base class inherited by all the controllers that have a view with a menu and that, when
 * the user clicks on a menu item, ask the user to save the state (ex: save grocery list items).
 */
public abstract class ControllerWithMenuThatSaves extends ControllerWithMenu {

    protected ControllerWithMenuThatSaves(HelpPage helpPage) {
        super(helpPage);
    }

    protected abstract void askSaveConfirmation();

    /**
     * Asks the user if he wants to save changes then logs out
     */
    @Override
    public void onLogout() {
        this.askSaveConfirmation();
        super.onLogout();
    }

    /**
     * Asks the user if he wants to save changes then shows the map
     */
    @Override
    public void onShowMap() {
        this.askSaveConfirmation();
        super.onShowMap();
    }

    /**
     * Asks the user if he wants to save changes then shows all the grocery lists
     */
    @Override
    public void onShowAllRecipes() {
        this.askSaveConfirmation();
        super.onShowAllRecipes();
    }

    /**
     * Asks the user if he wants to save changes then shows the Edit Profile view
     */
    @Override
    public void onShowEditProfile() {
        this.askSaveConfirmation();
        super.onShowEditProfile();
    }

    /**
     * Asks the user if he wants to save changes then shows all grocery lists
     */
    @Override
    public void onShowAllGroceryLists() {
        this.askSaveConfirmation();
        super.onShowAllGroceryLists();
    }
}
