package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.database.ProductDB;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseConnectionException;
import be.ac.ulb.infof307.g02.exceptions.database.ProductAlreadyExistsException;
import be.ac.ulb.infof307.g02.models.Product;
import be.ac.ulb.infof307.g02.views.CreateProductView;

/**
 * Controller of the create product view.
 */
public class CreateProductController extends Controller {

    /**
     * The observer is informed when a new product is created
     */
    private ProductCreationObserver observer;

    private ProductDB database;
    private CreateProductView view;

    /**
     * Creates the view to create a new product
     *
     * @param observer
     */
    public CreateProductController(ProductCreationObserver observer) {
        this.observer = observer;
        try {
            this.view = new CreateProductView(this);
            this.database = new ProductDB();
        } catch (DatabaseConnectionException e) {
            this.view.showDatabaseConnectionError();
        }
    }

    /**
     * Creates a product and adds it in the database. Inform the user if the
     * product already exists
     *
     * @param productName          The name of the new product
     * @param productUnit          The unit in which the product is measured
     * @param productLipids        Lipids contained in 100g
     * @param productProteins      Proteins contained in 100g
     * @param productCarbohydrates Carbohydrates contained in 100g
     */
    public void createProduct(String productName, Product.Unit productUnit, double productLipids, double productProteins, double productCarbohydrates) {
        try {
            Product newProduct = new Product(productName, productUnit, productLipids, productProteins, productCarbohydrates);
            this.database.addProduct(newProduct);
            this.observer.onProductCreated(newProduct);
            this.view.close();
            this.view.showSuccessPopup();

        } catch (ProductAlreadyExistsException e ) {
            this.view.showProductAlreadyExistsError();
        } catch (IllegalArgumentException e) {
            this.view.showInvalidName();

        }
    }

    public void notifyObserverWindowClosed() {
        this.observer.onCreateProductClosed();
    }


}