package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.database.GroceryListDB;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseConnectionException;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseException;
import be.ac.ulb.infof307.g02.exceptions.database.GroceryListInsertionException;
import be.ac.ulb.infof307.g02.exceptions.database.GroceryListItemInsertException;
import be.ac.ulb.infof307.g02.exceptions.model.ItemCreationException;
import be.ac.ulb.infof307.g02.models.GroceryList;

/**
 * Controller of the view displaying all the grocery lists of a User.
 */
public class GroceryListSelectionController extends SelectionController {
    /**
     * The title that needs to be passed to the selectionView
     */
    private static final String TITLE = "Your grocery lists";
    private GroceryListDB groceryListDB;

    public GroceryListSelectionController(ControllerMaster master) {
        super(master);
        try {
            this.groceryListDB = new GroceryListDB();
            this.setItemNames(this.groceryListDB.getAllGroceryListsName(this.master.getUser()));
            this.initializeView(TITLE, this.getItemNames());
        } catch (DatabaseConnectionException e) {
            this.view.showDatabaseConnectionError();
        }
    }

    /**
     * Creates the new grocery list, adds it to the DB and then shows the "Edit
     * Grocery List" screen with the newly created (empty) list. If the name is
     * already taken, warns the user and it doesn't create the list.
     */
    @Override
    protected void onCreateItem(String newListName) throws ItemCreationException {
        try {
            GroceryList groceryList = new GroceryList(newListName);
            this.groceryListDB.addGroceryList(this.master.getUser(), groceryList);
            this.master.onShowGroceryList(newListName);
        } catch (GroceryListInsertionException | GroceryListItemInsertException | IllegalArgumentException e) {
            throw new ItemCreationException();
        }
    }

    /**
     * Deletes a groceryList from the database
     *
     * @param listName name of the grocery list to delete
     */
    @Override
    protected void onDelete(String listName) throws DatabaseException {
        this.groceryListDB.deleteGroceryList(this.master.getUser(), listName);
    }

    /**
     * Shows the selected grocery list.
     *
     * @param choice Chosen grocery list
     */
    @Override
    public void onSelection(String choice) {
        this.master.onShowGroceryList(choice);
    }
}
