package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.database.RecipeDB;
import be.ac.ulb.infof307.g02.exceptions.database.*;
import be.ac.ulb.infof307.g02.exceptions.model.ItemCreationException;
import be.ac.ulb.infof307.g02.exceptions.model.RecipeCreationException;
import be.ac.ulb.infof307.g02.models.Recipe;

/**
 * Controller of the view displaying all the recipes of a User.
 */
public class RecipeSelectionController extends SelectionController {

    /**
     * The title that needs to be passed to the selectionView
     */
    private static final String TITLE = "Your recipes";
    private RecipeDB recipeDB;

    public RecipeSelectionController(ControllerMaster master) {
        super(master);
        try {
            this.recipeDB = new RecipeDB();
            this.setItemNames(this.recipeDB.getAllRecipesName(this.master.getUser()));
            this.initializeView(TITLE, this.getItemNames());

        } catch (DatabaseConnectionException e) {
            this.view.showDatabaseConnectionError();

        } catch (DatabaseException e) {
            this.view.showDataBaseInternalError();

        }
    }

    /**
     * Creates the new recipe, adds it to the DB and then shows the "Edit
     * Recipe" screen with the newly created (empty) recipe. If the name
     * already taken, warns the user and it doesn't create the recipe.
     */
    @Override
    protected void onCreateItem(String newRecipeName) throws ItemCreationException {
        try {
            Recipe recipe = new Recipe(newRecipeName);
            this.recipeDB.addRecipe(this.master.getUser(), recipe);
            this.master.onShowRecipe(newRecipeName);
        } catch (RecipeInsertionException | RecipeItemInsertException | RecipeCreationException e) {
            throw new ItemCreationException();
        } catch (NoSuchRecipeException e) {
            // Never happen because the createRecipe button
            // is only activated if the name is not empty.
        }
    }

    /**
     * Deletes a recipe from the database
     *
     * @param recipeName
     */
    @Override
    protected void onDelete(String recipeName) throws DatabaseException {
        this.recipeDB.deleteRecipe(this.master.getUser(), recipeName);
    }

    /**
     * Shows the selected recipe.
     *
     * @param recipeName
     */
    @Override
    public void onSelection(String recipeName) {
        try {
            this.master.onShowRecipe(recipeName);
        } catch (NoSuchRecipeException e) {
            this.getView().setErrorText("Couldn't switch to recipe view");
        } catch (RecipeCreationException e) {
            //Never will appear
        }
    }
}
