package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.database.UserDB;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseConnectionException;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseException;
import be.ac.ulb.infof307.g02.exceptions.database.UserNameTakenException;
import be.ac.ulb.infof307.g02.exceptions.model.UserCreationException;
import be.ac.ulb.infof307.g02.models.User;
import be.ac.ulb.infof307.g02.utils.CryptoSingleton;
import be.ac.ulb.infof307.g02.views.RegisterView;

/**
 * Controller of the register profile Window.
 */
public class RegisterController extends Controller {

    private UserDB database;
    private RegisterView view;


    public RegisterController(ControllerMaster master) {
        this.master = master;
        try {
            this.view = new RegisterView(this, this.master.getScene());
            this.database = new UserDB();
        } catch (DatabaseConnectionException e) {
            this.view.showDatabaseConnectionError();
        }
    }

    /**
     * Creates a new user and inserts it in the database
     *
     * @param userName String
     * @param password String
     */
    public void createUser(String userName, String password) {
        try {
            User newUser = new User(userName, password);
            this.database.addUser(newUser);
            CryptoSingleton.setupCryptoForUser(newUser);
            this.view.showSuccessPopup();
            this.master.onRegister();
        } catch (UserCreationException e) {
            this.view.showInvalidCredentialsError();
        } catch (UserNameTakenException e) {
            this.view.showUserNameTakenError();
        } catch (DatabaseException e) {
            this.view.showDataBaseInternalError();
        } catch (DatabaseConnectionException e) {
            this.view.showDatabaseConnectionError();
        }

    }

    /**
     * Goes to the login view
     */
    public void goToLogin() {
        this.master.onShowLogin();
    }
}
