package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.database.GroceryListDB;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseConnectionException;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseException;
import be.ac.ulb.infof307.g02.models.GroceryList;
import be.ac.ulb.infof307.g02.views.SelectBestTourGroceryListView;

import java.io.IOException;
import java.util.List;

/**
 * Controller of the view used to choose a GroceryList for the BestTourFinder algorithm.
 */
public class SelectBestTourGroceryListController extends Controller {

    private GroceryListDB database;
    private SelectBestTourGroceryListView view;

    public SelectBestTourGroceryListController(ControllerMaster master) {
        this.master = master;
        try {
            this.database = new GroceryListDB();
            this.view = new SelectBestTourGroceryListView(this);
        } catch (DatabaseConnectionException e) {
            this.view.showDatabaseConnectionError();
        } catch (IOException e) {
            // Don't need to handle this type of exception
            // It shouldn't happen
        }
    }

    /**
     * Gets all the grocery lists from the database
     *
     * @return
     */
    public List<String> getAllGroceryList() {
        return this.database.getAllGroceryListsName(this.master.getUser());
    }

    /**
     * Fetches the list selected by the user from the database and acknowledge the
     * master that all the information are now available
     *
     * @param groceryListName
     */
    public void onListSelected(String groceryListName) {
        try {
            GroceryList list = this.database.getGroceryList(this.master.getUser(), groceryListName);
            if (!list.isEmpty()) {
                this.view.close();
                this.master.onBestRouteAlgoReady(list);
            } else {
                this.view.showEmptyGroceryListError();

            }

        } catch (DatabaseException e) {
            this.view.showDataBaseInternalError();
        }
    }

    /**
     * Informs the ControllerMaster that the user has closed the view
     */
    public void onCloseSelectGroceryListView() {
        this.master.onCloseSelectGroceryListView();
    }
}
