package be.ac.ulb.infof307.g02.controllers;

import be.ac.ulb.infof307.g02.exceptions.database.DatabaseException;
import be.ac.ulb.infof307.g02.exceptions.model.ItemCreationException;
import be.ac.ulb.infof307.g02.views.HelpPage;
import be.ac.ulb.infof307.g02.views.Popup;
import be.ac.ulb.infof307.g02.views.SelectionView;

import java.util.List;


/**
 * Controller of the SelectionView used to display all the items of a user.
 * It is used to display all the grocery lists and all the recipes.
 */
public abstract class SelectionController extends ControllerWithMenu {

    protected SelectionView view;
    private List<String> itemNames;

    public SelectionController(ControllerMaster master) {
        super(HelpPage.ITEM_SELECTION);
        this.master = master;
    }

    // Abstract methods
    protected abstract void onCreateItem(String newListName) throws ItemCreationException;


    protected abstract void onDelete(String toDelete) throws DatabaseException;

    public abstract void onSelection(String choice);

    /**
     * Instantiate the view and fill it with all the possible choices.
     *
     * @param title
     * @param choices
     */
    public void initializeView(String title, List<String> choices) {
        this.view = new SelectionView(this, this.master.getScene(), title);

        for (String choice : choices) {
            this.view.createNewEntry(choice);
        }
    }

    /**
     * Creates the new grocery list, adds it to the DB and then shows the "Edit
     * Grocery List" screen with the newly created (empty) list. If the name is
     * already taken, warns the user and it doesn't create the list.
     *
     * @param newItemName
     */
    public void createNewItem(String newItemName) {
        if (this.itemNames.contains(newItemName)) {
            this.view.setErrorText("A list with that name already exists.");
            return;
        } else {
            this.view.setErrorText("");
        }

        try {
            this.onCreateItem(newItemName);
        } catch (ItemCreationException e) {
            Popup.showPopupErrorCreatingItem();
        }
    }


    /**
     * Deletes a groceryList from the database
     *
     * @param choice
     */
    public void deleteItem(String choice) {
        try {
            this.onDelete(choice);
        } catch (DatabaseException e) {
            this.view.showDataBaseInternalError();
        }
        this.itemNames.remove(choice);
    }

    public SelectionView getView() {
        return this.view;
    }

    /**
     * Gets the names of the selectable items
     */
    public List<String> getItemNames() {
        return this.itemNames;
    }

    public void setItemNames(List<String> itemNames) {
        this.itemNames = itemNames;
    }
}

