package be.ac.ulb.infof307.g02.database;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseConnectionException;

/**
 * This class is used to get access to the DatabaseConnection object. We use the singleton pattern
 * because we only want one connection per database at the time.
 * We get either the real DatabaseConnection or the test DatabaseConnection (depending on whether we're in test mode).
 */
public final class DatabaseConnectionSingleton {

    private static DatabaseConnection databaseConnection = null;

    /**
     * Utility class. Should not be able to instantiate it.
     */
    private DatabaseConnectionSingleton() {
    }

    /**
     * Returns the database connection, instantiating it if doesn't exist yet.
     *
     * @throws DatabaseConnectionException
     */
    public static synchronized DatabaseConnection getDatabaseConnection() throws DatabaseConnectionException {
        if (databaseConnection == null) {
            if (Constants.IN_TEST_MODE) {
                databaseConnection = new DatabaseConnection(Constants.TEST_DATABASE_PATH);
            } else {
                databaseConnection = new DatabaseConnection(Constants.PRODUCTION_DATABASE_PATH);
            }
        }
        return databaseConnection;
    }
}
