package be.ac.ulb.infof307.g02.database;

import be.ac.ulb.infof307.g02.constants.ConstantsLoader;
import be.ac.ulb.infof307.g02.models.*;
import be.ac.ulb.infof307.g02.utils.CryptoSingleton;
import be.ac.ulb.infof307.g02.utils.Utils;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * Fills the database with some sample information.
 */
public final class DatabaseFiller {

    public static void main(String[] args) throws Exception {
        ConstantsLoader.loadAllConstants();
        Utils.setupKeyStore();
        KeyStorer keyStorer = new KeyStorer(DatabaseConnectionSingleton.getDatabaseConnection());
        keyStorer.emptyKeyStore();
        fillDatabase();
    }


    /**
     * Fills the database with default values
     * @throws Exception
     */
    private static void fillDatabase() throws Exception {
        System.out.println("Filling Database...");
        DatabaseConnection db = DatabaseConnectionSingleton.getDatabaseConnection();
        db.empty();

        ShopDB shopDB = new ShopDB();
        ProductDB productDB = new ProductDB();
        GroceryListDB groceryBD = new GroceryListDB();

        Product prod1 = new Product("banana", Product.Unit.KG, 0.3, 1.1, 23);
        Product prod2 = new Product("tomato", Product.Unit.KG, 0.2, 0.9, 3.9);
        Product prod3 = new Product("salt", Product.Unit.KG, 0, 0, 0);
        Product prod4 = new Product("milk", Product.Unit.LITER, 1, 3.4, 5);
        Product prod5 = new Product("water", Product.Unit.LITER, 0, 0, 0);
        Product prod6 = new Product("kiwi", Product.Unit.UNIT, 0.3, 1.1, 23);
        Product prod7 = new Product("egg", Product.Unit.UNIT, 11, 13, 1.1);
        Product prod8 = new Product("computer", Product.Unit.UNIT, 0, 0, 0);
        Product prod9 = new Product("pen", Product.Unit.UNIT, 0, 0, 0);
        Product prod10 = new Product("cola", Product.Unit.LITER, 0, 0.1, 10);
        Product prod11 = new Product("dürum", Product.Unit.UNIT, 5, 0.1, 10);
        Product prod12 = new Product("beer", Product.Unit.LITER, 0.1, 0.1, 0.3);
        Product prod13 = new Product("pizza", Product.Unit.UNIT, 3, 0.5, 1.5);
        Product prod14 = new Product("root", Product.Unit.LITER, 0, 0, 0.1);
        Product prod15 = new Product("bottle of Henri Jayer Richebourg Grand Cru", Product.Unit.UNIT, 0, 0.1, 4);
        Product prod16 = new Product("vodka", Product.Unit.LITER, 0, 0.1, 10);
        Product prod17 = new Product("nuggets", Product.Unit.KG, 4, 6.2, 0);
        Product prod18 = new Product("red wine", Product.Unit.LITER, 0, 0, 0);
        Product prod19 = new Product("bread", Product.Unit.KG, 0.1, 0, 0);
        Product prod20 = new Product("pasta", Product.Unit.KG, 0, 0, 0);
        Product prod21 = new Product("barley sugar", Product.Unit.UNIT, 0, 0, 9);
        Product prod22 = new Product("ice cube", Product.Unit.KG, 0, 0, 0);
        Product prod23 = new Product("ice berg", Product.Unit.KG, 0, 0, 0);
        Product prod24 = new Product("chewing gum", Product.Unit.UNIT, 0, 0, 1.5);
        Product prod25 = new Product("mussles", Product.Unit.KG, 0.8, 0, 0);


        productDB.addProduct(prod1);
        productDB.addProduct(prod2);
        productDB.addProduct(prod3);
        productDB.addProduct(prod4);
        productDB.addProduct(prod5);
        productDB.addProduct(prod6);
        productDB.addProduct(prod7);
        productDB.addProduct(prod8);
        productDB.addProduct(prod9);
        productDB.addProduct(prod10);
        productDB.addProduct(prod11);
        productDB.addProduct(prod12);
        productDB.addProduct(prod13);
        productDB.addProduct(prod14);
        productDB.addProduct(prod15);
        productDB.addProduct(prod16);
        productDB.addProduct(prod17);
        productDB.addProduct(prod18);
        productDB.addProduct(prod19);
        productDB.addProduct(prod20);
        productDB.addProduct(prod21);
        productDB.addProduct(prod22);
        productDB.addProduct(prod23);
        productDB.addProduct(prod24);
        productDB.addProduct(prod25);



        Position pos1 = new Position(50.849319, 4.356506);
        Position pos2 = new Position(50.849319, 4.357506);
        Position pos3 = new Position(50.849319, 4.355506);
        Position pos4 = new Position(50.8444, 4.3559);
        Position pos5 = new Position(50.818035, 4.392899); //snack shop's
        Position pos6 = new Position(50.816853, 4.389188); //carrefour market ixelles
        Position pos7 = new Position(50.822681, 4.403984); //Delhaize hankar
        Position pos8 = new Position(50.825003, 4.397895); //Colruyt Auderghem
        Position pos9 = new Position(49.544069, 5.796673); //Auchan Mont st martin
        Position pos10 = new Position(49.613527, 5.812718); // Cora Messancy
        Position pos11 = new Position(66.503179, 25.729522); //finland
        Position pos12 = new Position(50.844953, 4.385596); //Roots Store
        Position pos13 = new Position(50.845053, 4.417025); //picard
        Position pos14 = new Position(50.832076, 4.356523); //Mig's World Wines
        Position pos15 = new Position(50.815223, 4.389063); //Okay ixelles
        Position pos16 = new Position(50.816018, 4.389834); //PAKI


        Schedule schedule = new Schedule();//la semaine
        schedule.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.MONDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.MONDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.TUESDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.TUESDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.WEDNESDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.THURSDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.THURSDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.FRIDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(19, 0)), Day.FRIDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(9, 0), new Time(20, 0)), Day.SATURDAY);

        Schedule schedule2 = new Schedule();//la semaine et jf et dim sans lundi
        schedule2.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.TUESDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.TUESDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(14, 30)), Day.WEDNESDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.THURSDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.THURSDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.FRIDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(19, 0)), Day.FRIDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(9, 0), new Time(20, 0)), Day.SATURDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(9, 30), new Time(12, 30)), Day.SUNDAY);
        schedule2.addTimeSlot(new TimeSlot(new Time(9, 30), new Time(12, 30)), Day.PUBLIC_HOLIDAY);

        Schedule schedule3 = new Schedule();//la semaine et jf et dim sans lundi et merc
        schedule3.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.TUESDAY);
        schedule3.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.TUESDAY);
        schedule3.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.THURSDAY);
        schedule3.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.FRIDAY);
        schedule3.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(19, 0)), Day.FRIDAY);
        schedule3.addTimeSlot(new TimeSlot(new Time(9, 0), new Time(20, 0)), Day.SATURDAY);
        schedule3.addTimeSlot(new TimeSlot(new Time(9, 30), new Time(12, 30)), Day.SUNDAY);
        schedule3.addTimeSlot(new TimeSlot(new Time(9, 30), new Time(12, 30)), Day.PUBLIC_HOLIDAY);

        Schedule schedule4 = new Schedule();//all time
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(3, 0)), Day.MONDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.MONDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(3, 0)), Day.TUESDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.TUESDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(3, 0)), Day.WEDNESDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.WEDNESDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(6, 0)), Day.THURSDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.THURSDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(3, 0)), Day.FRIDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.FRIDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(7, 0)), Day.SATURDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.SATURDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(7, 0)), Day.SUNDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.SUNDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(0, 0), new Time(7, 0)), Day.PUBLIC_HOLIDAY);
        schedule4.addTimeSlot(new TimeSlot(new Time(18, 0), new Time(23, 59)), Day.PUBLIC_HOLIDAY);

        Schedule schedule5 = new Schedule();//santa
        schedule5.addTimeSlot(new TimeSlot(new Time(11, 0), new Time(17, 30)), Day.PUBLIC_HOLIDAY);


        Article art1 = new Article(prod1, 4.99);
        Article art2 = new Article(prod2, 3.78);
        Article art3 = new Article(prod3, 2.49);
        Article art4 = new Article(prod4, 1.49);
        Article art5 = new Article(prod5, 0.99);
        Article art6 = new Article(prod6, 0.35);
        Article art7 = new Article(prod7, 0.20);
        Article art8 = new Article(prod8, 1499.90);
        Article art9 = new Article(prod9, 1.99);
        Article art10 = new Article(prod10, 6.66);
        Article art11 = new Article(prod11, 4.50);
        Article art12 = new Article(prod12, 1.80);
        Article art13 = new Article(prod13, 4.99);
        Article art14 = new Article(prod14, 15.00);
        Article art15;
        Article art16 = new Article(prod16, 16.99);
        Article art17 = new Article(prod17, 7.49);
        Article art18 = new Article(prod18, 7.99);
        Article art19 = new Article(prod19, 1.49);
        Article art20 = new Article(prod20, 2.19);
        Article art21 = new Article(prod21, 3.50);
        Article art22;
        Article art23;
        Article art24 = new Article(prod24, 2.00);
        Article art25;
        //shop 1
        Map<Product, Article> stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art6.getProduct(), art6);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art21.getProduct(), art21);
        stock.put(art24.getProduct(), art24);
        Shop shop1 = new Shop(1, "Carrefour Market", schedule, pos1, stock);
        shopDB.addShop(shop1);

        //shop6
        art1 = new Article(prod1, 3.89);
        art5 = new Article(prod5, 1.09);
        art17 = new Article(prod17, 8.89);
        art20 = new Article(prod20, 2.09);
        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art6.getProduct(), art6);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art24.getProduct(), art24);
        Shop shop6 = new Shop(1, "Carrefour Market Ixelles", schedule, pos6, stock);
        shopDB.addShop(shop6);

        //shop7
        art1 = new Article(prod1, 5.89);
        art12 = new Article(prod12, 3.09);
        art17 = new Article(prod17, 7.99);
        art24 = new Article(prod24, 2.99);
        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art6.getProduct(), art6);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art24.getProduct(), art24);
        Shop shop7 = new Shop(1, "Delhaize Hankar", schedule, pos7, stock);
        shopDB.addShop(shop7);

        //shop8
        art1 = new Article(prod1, 5.49);
        art2 = new Article(prod2, 4.09);
        art17 = new Article(prod17, 3.00);
        art19 = new Article(prod19, 2.79);
        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art6.getProduct(), art6);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art16.getProduct(), art16);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art24.getProduct(), art24);
        Shop shop8 = new Shop(1, "Colruyt Auderghem", schedule, pos8, stock);
        shopDB.addShop(shop8);

        //shop9
        art1 = new Article(prod1, 5.62);
        art2 = new Article(prod2, 4.14);
        art3 = new Article(prod3, 8.00);
        art24 = new Article(prod24, 2.79);
        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art6.getProduct(), art6);
        stock.put(art7.getProduct(), art7);
        stock.put(art8.getProduct(), art8);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art24.getProduct(), art24);
        Shop shop9 = new Shop(1, "Auchan Mont-st-martin", schedule, pos9, stock);
        shopDB.addShop(shop9);

        //shop10
        art4 = new Article(prod4, 2.45);
        art6 = new Article(prod6, 0.80);
        art9 = new Article(prod9, 0.99);
        art24 = new Article(prod24, 2.35);
        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art6.getProduct(), art6);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art24.getProduct(), art24);
        Shop shop10 = new Shop(1, "Cora Messancy", schedule, pos10, stock);
        shopDB.addShop(shop10);

        //shop15
        art1 = new Article(prod1, 5.49);
        art2 = new Article(prod2, 4.09);
        art13 = new Article(prod13, 11.00);
        art15 = new Article(prod15, 19999.99);
        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art6.getProduct(), art6);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art15.getProduct(), art15);
        Shop shop15 = new Shop(1, "Okay Ixelles", schedule, pos15, stock);
        shopDB.addShop(shop15);


        //shop3
        art9 = new Article(prod9, 1.89);
        art20 = new Article(prod20, 2.49);

        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art24.getProduct(), art24);
        Shop shop3 = new Shop(1, "Aldi", schedule, pos3, stock);
        shopDB.addShop(shop3);

        //sho4
        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art7.getProduct(), art7);
        stock.put(art9.getProduct(), art9);
        stock.put(art10.getProduct(), art10);
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        stock.put(art24.getProduct(), art24);
        Shop shop4 = new Shop(1, "NoName", schedule, pos4, stock);
        shopDB.addShop(shop4);

        //shop2
        art1 = new Article(prod1, 4.49);
        art2 = new Article(prod2, 3.20);
        art4 = new Article(prod4, 1.39);
        art5 = new Article(prod5, 0.79);
        art7 = new Article(prod7, 0.12);
        art10 = new Article(prod10, 5.66);
        art18 = new Article(prod18, 7.49);
        art19 = new Article(prod19, 0.99);
        art20 = new Article(prod20, 1.99);

        stock = new HashMap<>();
        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
        stock.put(art3.getProduct(), art3);
        stock.put(art4.getProduct(), art4);
        stock.put(art5.getProduct(), art5);
        stock.put(art7.getProduct(), art7);
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art13.getProduct(), art13);
        stock.put(art18.getProduct(), art18);
        stock.put(art19.getProduct(), art19);
        stock.put(art20.getProduct(), art20);
        Shop shop2 = new Shop(1, "Colruyt", schedule, pos2, stock);
        shopDB.addShop(shop2);

        //shop14
        art15 = new Article(prod15, 13652.00);
        art18 = new Article(prod18, 10.99);
        stock = new HashMap<>();
        stock.put(art15.getProduct(), art15);
        stock.put(art18.getProduct(), art18);
        Shop shop14 = new Shop(1, "Mig's World Wines", schedule3, pos14, stock);
        shopDB.addShop(shop14);

        //shop12
        stock = new HashMap<>();
        stock.put(art14.getProduct(), art14);
        Shop shop12 = new Shop(1, "Roots Store", schedule3, pos12, stock);
        shopDB.addShop(shop12);

        //shop5
        art10 = new Article(prod10, 4.50);
        stock = new HashMap<>();
        stock.put(art10.getProduct(), art10);
        stock.put(art11.getProduct(), art11);
        Shop shop5 = new Shop(1, "snack Shop's", schedule, pos5, stock);
        shopDB.addShop(shop5);

        //shop11
        art21 = new Article(prod21, 0.01);
        art22 = new Article(prod22, 0.01);
        art23 = new Article(prod23, 0.01);
        stock = new HashMap<>();
        stock.put(art21.getProduct(), art21);
        stock.put(art22.getProduct(), art22);
        stock.put(art23.getProduct(), art23);
        Shop shop11 = new Shop(1, "Santa's Shop", schedule5, pos11, stock);
        shopDB.addShop(shop11);

        //shop16
        art10 = new Article(prod10, 6.00);
        art12 = new Article(prod12, 3.00);
        art16 = new Article(prod16, 22.00);
        art18 = new Article(prod18, 18.00);
        art24 = new Article(prod24, 3.00);
        stock = new HashMap<>();
        stock.put(art10.getProduct(), art10);
        stock.put(art12.getProduct(), art12);
        stock.put(art16.getProduct(), art16);
        stock.put(art18.getProduct(), art18);
        stock.put(art24.getProduct(), art24);
        Shop shop16 = new Shop(1, "PAKI", schedule4, pos16, stock);
        shopDB.addShop(shop16);

        //shop13
        art13 = new Article(prod13, 4.00);
        art17 = new Article(prod17, 6.99);
        art22 = new Article(prod22, 1.79);
        art25 = new Article(prod25, 9.99);
        stock = new HashMap<>();
        stock.put(art13.getProduct(), art13);
        stock.put(art17.getProduct(), art17);
        stock.put(art22.getProduct(), art22);
        stock.put(art25.getProduct(), art25);
        Shop shop13 = new Shop(1, "Picard", schedule2, pos13, stock);
        shopDB.addShop(shop13);


        // User specific data, will be encrypted

        UserDB userDB = new UserDB();
        User user1 = new User("bob", "bob123456789");
        userDB.addUser(user1);
        CryptoSingleton.setupCryptoForUser(user1);


        ProductAmount item1 = new ProductAmount(prod1, 2);
        ProductAmount item2 = new ProductAmount(prod2, 1);
        List<ProductAmount> itemList = Arrays.asList(item1, item2);
        GroceryList list = new GroceryList("mylist", itemList);
        groceryBD.addGroceryList(user1, list);

        User user2 = new User("a", "a123456789");
        User admin = new User("admin", "admin123");

        userDB.addUser(user2);
        CryptoSingleton.setupCryptoForUser(user2);
        userDB.addUser(admin);
        CryptoSingleton.setupCryptoForUser(admin);

        System.out.println("Done.");


    }
}
