package be.ac.ulb.infof307.g02.database;

import be.ac.ulb.infof307.g02.utils.Crypto;

import java.sql.PreparedStatement;
import java.sql.SQLException;


/**
 * Wrapper around a prepared statement that encrypts all the values by default.
 * However it is still possible to set unencrypted values by calling special methods.
 */
public class EncryptedPreparedStatement {
    private final PreparedStatement preparedStatement;
    private final Crypto crypto;

    public EncryptedPreparedStatement(PreparedStatement preparedStatement, Crypto crypto) {
        this.preparedStatement = preparedStatement;
        this.crypto = crypto;
    }

    public void setUnencryptedString(int i, String value) throws SQLException {
        this.preparedStatement.setString(i, value);
    }

    public void setString(int index, String value) throws SQLException {
        this.preparedStatement.setBytes(index, this.crypto.encrypt(value));
    }

    public void setInt(int index, int value) throws SQLException {
        this.preparedStatement.setBytes(index, this.crypto.encrypt(value));
    }

    public void setDouble(int index, double value) throws SQLException {
        this.preparedStatement.setBytes(index, this.crypto.encrypt(value));
    }

    public EncryptedResultSet getEncryptedResultSet() throws SQLException {
        return new EncryptedResultSet(this.preparedStatement.getResultSet());
    }

    public void execute() throws SQLException {
        this.preparedStatement.execute();
    }

    public void close() throws SQLException {
        this.preparedStatement.close();
    }
}
