package be.ac.ulb.infof307.g02.database;

import be.ac.ulb.infof307.g02.utils.Crypto;
import be.ac.ulb.infof307.g02.utils.CryptoSingleton;

import java.sql.ResultSet;
import java.sql.SQLException;

import static be.ac.ulb.infof307.g02.utils.Utils.bytesToDouble;
import static be.ac.ulb.infof307.g02.utils.Utils.bytesToInt;

/**
 * Wrapper around a Result Set that automatically decrypts the values of a given result set.
 */
public class EncryptedResultSet {
    private final ResultSet resultSet;
    private final Crypto crypto;

    public EncryptedResultSet(ResultSet resultSet) {
        this.resultSet = resultSet;
        this.crypto = CryptoSingleton.getCrypto();
    }

    public boolean next() throws SQLException {
        return this.resultSet.next();
    }

    public String getString(String columnName) throws SQLException {
        return decryptString(this.resultSet.getBytes(columnName));
    }

    public int getInt(String columnName) throws SQLException {
        return decryptInt(this.resultSet.getBytes(columnName));
    }

    public Double getDouble(String columnName) throws SQLException {
        return decryptDouble(this.resultSet.getBytes(columnName));
    }

    private String decryptString(byte[] bytes) {
        return new String(this.crypto.decrypt(bytes));
    }

    private int decryptInt(byte[] bytes) {
        return bytesToInt(this.crypto.decrypt(bytes));
    }

    private double decryptDouble(byte[] bytes) {
        return bytesToDouble(this.crypto.decrypt(bytes));
    }


}
