package be.ac.ulb.infof307.g02.database;

import be.ac.ulb.infof307.g02.exceptions.database.DatabaseConnectionException;

import java.sql.SQLException;

/**
 * This abstract base class is used for each DB. It gets the connection to the databaseConnection
 * and adds a method to empty all tables.
 */
public abstract class ObjectDB {
    private DatabaseConnection databaseConnection;

    /**
     * Class constructor that fetches the connection to the production database. Throws an exception if
     * the connection is not successful.
     *
     * @throws DatabaseConnectionException
     */
    public ObjectDB() throws DatabaseConnectionException {
        this.databaseConnection = DatabaseConnectionSingleton.getDatabaseConnection();
    }

    /**
     * Class constructor that stores the given database connection for later use.
     *
     * @param databaseConnection
     */
    public ObjectDB(DatabaseConnection databaseConnection) {
        this.databaseConnection = databaseConnection;
    }

    /**
     * Empties all the tables in the database
     *
     * @throws SQLException
     */
    public void emptyAllTables() throws SQLException {
        this.databaseConnection.empty();
    }

    protected DatabaseConnection getDatabaseConnection() {
        return this.databaseConnection;
    }
}
