package be.ac.ulb.infof307.g02.models;

import java.util.Objects;

/**
 * Represents an article (product + price) that is stored in a shop.
 */
public class Article {

    private Product product;
    private double price;

    public Article(Product product, double price) {
        if (price <= 0) {
            throw new IllegalArgumentException("Prices must be positive.");
        }

        this.product = product;
        this.price = price;
    }

    public Product getProduct() {
        return new Product(this.product);
    }

    public double getPrice() {
        return this.price;
    }

    /**
     * Checks if two articles are equal.
     *
     * @param o
     */
    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Article article = (Article) o;
        return Objects.equals(this.product, article.product) &&
                Objects.equals(this.price, article.price);
    }

    @Override
    public int hashCode() {
        return Objects.hash(this.product, this.price);
    }

    public String getProductName() {
        return this.product.getName();
    }

    public String getProductUnitName() {
        return this.product.getUnitName();
    }

    public double getProductProteins() {
        return this.product.getProteinGramsPerUnit();
    }

    public double getProductLipids() {
        return this.product.getLipidGramsPerUnit();
    }

    public double getProductCarbohydrates() {
        return this.product.getCarbohydrateGramsPerUnit();
    }
}
