package be.ac.ulb.infof307.g02.models;

import be.ac.ulb.infof307.g02.constants.Constants;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

/**
 * Calculates the Autochef score. This score is used to rank the shops using
 * both distance and price.
 */
public class AutoChefScoreCalculator {

    /**
     * Maximum value allowed for a score. All scores are between 0 and MAX_SCORE.
     */
    private static final int MAX_SCORE = 10;

    /**
     * Compute a score based on the distance to a shop and the price of a grocery list.
     * The score is relative to the minimum and maximum score. To evaluate the cost
     * of the path to the store, it uses the price that the user would pay per
     * kilometer.
     *
     * @param priceList     The list of the prices of the list items
     * @param distancesList The list of distances between the user and the shops
     * @return The AutoChef Score out of 10
     */
    public static List<Double> computeScore(List<Double> priceList, List<Double> distancesList) {
        List<Double> scores = new ArrayList<>(distancesList);
        if (priceList.isEmpty()) {
            return scores;
        }
        for (int i = 0; i < scores.size(); i++) {
            scores.set(i, (scores.get(i) * Constants.PRICE_PER_KM + priceList.get(i)));
        }

        double min = Collections.min(scores);
        for (int i = 0; i < scores.size(); i++) {
            scores.set(i, scores.get(i) - min);
        }

        double max = Collections.max(scores);
        // if the min score = the max score
        if (max == 0) {
            //set all scores to 10
            for (int i = 0; i < scores.size(); i++) {
                scores.set(i, 10.0);
            }
        } else {
            for (int i = 0; i < scores.size(); i++) {
                scores.set(i, scores.get(i) * (-MAX_SCORE / max) + MAX_SCORE);
            }
        }

        return scores;

    }

}
