package be.ac.ulb.infof307.g02.models;

import java.util.Objects;

/**
 * Represents the position of an element on the map (latitude, longitude)
 */
public class Position {
    private static final int MAX_LATITUDE = 90;
    private static final int MIN_LATITUDE = -90;
    private static final int MAX_LONGITUDE = 180;
    private static final int MIN_LONGITUDE = -180;
    private double latitude;
    private double longitude;

    public Position(double latitude, double longitude) {
        if (!areCoordinatesValid(latitude, longitude)) {
            throw new IllegalArgumentException(
                    "Latitude must be between -90 and 90 and longitude between -180 and 180");
        }

        this.latitude = latitude;
        this.longitude = longitude;
    }

    public Position(Position position) {
        this(position.getLatitude(), position.getLongitude());
    }

    /**
     * Checks if the coordinates are valid.
     * The latitude can vary between -90 and 90 and while the longitude can vary between -180 and 180.
     *
     * @param latitude
     * @param longitude
     * @return
     */
    public static boolean areCoordinatesValid(double latitude, double longitude) {
        return (latitude <= MAX_LATITUDE && latitude >= MIN_LATITUDE) &&
                (longitude <= MAX_LONGITUDE && longitude >= MIN_LONGITUDE);
    }

    public double getLatitude() {
        return this.latitude;
    }

    public double getLongitude() {
        return this.longitude;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Position position = (Position) o;
        return Double.compare(position.latitude, this.latitude) == 0 &&
                Double.compare(position.longitude, this.longitude) == 0;
    }

    @Override
    public int hashCode() {
        return Objects.hash(this.latitude, this.longitude);
    }
}