package be.ac.ulb.infof307.g02.models;

import java.util.Objects;

/**
 * Represents a ProductAmount (product + amount)
 */
public class ProductAmount {

    private Product product;
    private double amount;

    public ProductAmount(Product product, double amount) {
        if (amount <= 0) {
            throw new IllegalArgumentException();
        }
        this.product = product;
        this.amount = amount;
    }

    public Product getProduct() {
        return new Product(this.product);
    }

    public double getAmount() {
        return this.amount;
    }

    public void setAmount(double amount) {
        this.amount = amount;
    }

    public String getProductName() {
        return this.product.getName();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ProductAmount that = (ProductAmount) o;
        return Double.compare(that.amount, this.amount) == 0 &&
                Objects.equals(this.product, that.product);
    }


    @Override
    public int hashCode() {
        return Objects.hash(this.product, this.amount);
    }

    /**
     * @return A string of the form "ProductName - amount unit" (ex: "Banana - 2.0 Unit)
     */
    @Override
    public String toString() {
        return this.product.getName() + " - " + this.amount + " " + this.product.getUnitName();
    }
}
