package be.ac.ulb.infof307.g02.models;

import java.io.Serializable;
import java.util.Objects;

/**
 * Class representing a time (Hour:Minute)
 */
public class Time implements Serializable {

    private static final int NB_OF_HOURS_IN_DAY = 23;
    private static final int NB_OF_MINUTES_IN_HOUR = 59;
    private static final int MIN_HOURS = 0;
    private static final int MIN_MINUTES = 0;

    /**
     * Attributes a unique ID to the class to make serialization work. This ID is used
     * to make sure that the deserialized object is of this class.
     */
    private static final long serialVersionUID = 3307409715809363925L;
    private int hour;
    private int minute;

    public Time(int hour, int minute) throws IllegalArgumentException {
        if (hour < MIN_HOURS || hour > NB_OF_HOURS_IN_DAY || minute < MIN_MINUTES || minute > NB_OF_MINUTES_IN_HOUR) {
            throw new IllegalArgumentException();
        }
        this.hour = hour;
        this.minute = minute;
    }

    /**
     * Copy constructor
     *
     * @param otherTime
     */
    public Time(Time otherTime) {
        this(otherTime.getHour(), otherTime.getMinute());
    }

    public int getHour() {
        return this.hour;
    }

    public int getMinute() {
        return this.minute;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Time time = (Time) o;
        return this.hour == time.hour &&
                this.minute == time.minute;
    }

    @Override
    public int hashCode() {

        return Objects.hash(this.hour, this.minute);
    }

    public boolean isAfter(Time other) {
        if (other.getHour() > this.hour) {
            return false;
        } else {
            return other.getHour() < this.hour || other.getMinute() < this.minute;
        }
    }
}
