package be.ac.ulb.infof307.g02.utils;

import be.ac.ulb.infof307.g02.models.Article;
import be.ac.ulb.infof307.g02.models.Shop;
import be.ac.ulb.infof307.g02.views.FileSelectorView;

import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

/**
 * Responsible to export the stock of a shop into a csv file
 */
public class ArticlesExporter {
    /**
     * Converts the stock of a shop into a string formatted for a CSV file
     *
     * @param shop
     * @return formatted string
     */
    private static String stockToCsvFormat(Shop shop) {
        StringBuilder sb = new StringBuilder();
        sb.append(Headers.toCSV());
        for (Article article : shop.getStock().values()) {
            sb.append(article.getProductName());
            sb.append(',');
            sb.append(article.getProductUnitName());
            sb.append(',');
            sb.append(article.getPrice());
            sb.append(',');
            sb.append(article.getProductLipids());
            sb.append(',');
            sb.append(article.getProductProteins());
            sb.append(',');
            sb.append(article.getProductCarbohydrates());
            sb.append('\n');
        }

        return sb.toString();
    }

    /**
     * Saves the content into a file
     *
     * @param content
     * @param file
     */
    private static void saveFile(String content, File file) {
        try {
            FileWriter fileWriter = new FileWriter(file);
            fileWriter.write(content);
            fileWriter.close();
        } catch (IOException ex) {
            // Will never happen because the fileSelector force the user to select a correct file.
        }
    }

    /**
     * Converts a stock into a string, displays a file chooser and saves the
     * file
     *
     * @param shop
     */
    public static void exportFrom(Shop shop) {
        String stringToSave = stockToCsvFormat(shop);
        FileSelectorView fileSelectorView = new FileSelectorView();
        File file = fileSelectorView.getSelectedFileToSave();

        if (!file.getName().contains(".csv")) {
            file = new File(file.getAbsolutePath() + ".csv");
        }
        saveFile(stringToSave, file);

    }
}
