package be.ac.ulb.infof307.g02.utils;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.database.KeyStorer;

import java.io.*;
import java.nio.ByteBuffer;
import java.util.HashSet;
import java.util.List;


public class Utils {

    /**
     * When comparing doubles, we consider them equal if the difference between them is inferior
     * to this value.
     */
    public static final double DOUBLE_COMPARISON_MAX_DIFFERENCE_ALLOWED = 0.00000001;

    private static final int NUM_BYTES_IN_INT = 4;
    private static final int NUM_BYTES_IN_DOUBLE = 8;

    /**
     * Utility class: should not be instantiated
     */
    private Utils() {
    }

    public static boolean equalsDouble(double a, double b) {
        return Math.abs(a - b) < DOUBLE_COMPARISON_MAX_DIFFERENCE_ALLOWED;
    }

    /**
     * Returns whether the string contains a special character. A special
     * character is any of: (space), !, ", #, $, &, ', (, ), *, +, (comma), -,
     * ., /, ;, <, =, >, ?, @, [, ^, ], _, ', {, }, ~
     *
     * @param string
     * @return whether the string contains a special character
     */
    public static boolean hasSpecialChar(String string) {
        // Special Character list taken from OWASP
        String encodedSpecialCharacterList = " !\"#$%&'()*+,-./;<=>?@\\[^\\]_`{}~";
        return string.matches(".*[" + encodedSpecialCharacterList + "]+.*");
    }

    public static double round(double value, int precision) {
        int scale = (int) Math.pow(10, precision);
        return (double) Math.round(value * scale) / scale;
    }

    public static byte[] toByteArray(int value) {
        ByteBuffer byteBuffer = ByteBuffer.allocate(NUM_BYTES_IN_INT);
        byteBuffer.putInt(value);
        return byteBuffer.array();
    }

    public static byte[] toByteArray(double value) {
        ByteBuffer byteBuffer = ByteBuffer.allocate(NUM_BYTES_IN_DOUBLE);
        byteBuffer.putDouble(value);
        return byteBuffer.array();
    }

    public static int bytesToInt(byte[] bytes) {
        ByteBuffer wrapped = ByteBuffer.wrap(bytes);
        return wrapped.getInt();
    }

    public static double bytesToDouble(byte[] bytes) {
        ByteBuffer wrapped = ByteBuffer.wrap(bytes);
        return wrapped.getDouble();
    }

    public static <T> boolean listsHaveSameElements(List<T> list1, List<T> list2) {
        return new HashSet<>(list1).equals(new HashSet<>(list2));
    }

    public static void setupKeyStore() throws IOException {
        File keyStoreFile = new File(Constants.KEYSTORE_FILE_PATH);
        if (!fileExists(keyStoreFile)) {
            InputStream keystoreInputStream = KeyStorer.getKeystoreResourceInputStream();
            FileOutputStream fileOutputStream = new FileOutputStream(keyStoreFile);
            copyIntoStreamIntoAnother(keystoreInputStream, fileOutputStream);
        }
    }

    public static void copyIntoStreamIntoAnother(InputStream inputStream, OutputStream outputStream) throws IOException {
        byte[] buffer = new byte[4096];
        int totalNumBytesRead = inputStream.read(buffer);
        while (totalNumBytesRead > 0) { // =-1 if we reached the end of the input stream
            outputStream.write(buffer, 0, totalNumBytesRead);
            totalNumBytesRead = inputStream.read(buffer);
        }
    }

    public static boolean fileExists(File file) {
        return file.exists() && !file.isDirectory();
    }
}
