package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.EditAccountController;
import javafx.beans.binding.Bindings;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.TextField;

import java.io.IOException;

/**
 * View allowing the User to edit his account.
 */
public class EditAccountView extends ViewWithMenu {

    /**
     * The fxml resource for the view
     */
    private static final String EDIT_ACCOUNT_FXML = "editAccount.fxml";

    /**
     * Used the set the color of a label to red
     */
    private static final String FX_TEXT_FILL_RED = "-fx-text-fill: red;";
    @FXML
    private TextField userNameField;
    @FXML
    private TextField passwordField;
    @FXML
    private TextField confirmPasswordField;
    @FXML
    private TextField currentPasswordField;
    @FXML
    private Button saveButton;
    @FXML
    private Label passwordInfoLabel;
    @FXML
    private Label userNameInfoLabel;
    @FXML
    private Label errorLabel;

    private EditAccountController editAccountController;

    /**
     * Loads the fxml and creates the menu
     *
     * @param controller
     * @param scene
     */
    public EditAccountView(EditAccountController controller, Scene scene) {
        super(controller);
        this.editAccountController = controller;
        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + EDIT_ACCOUNT_FXML));
            loader.setController(this);
            scene.setRoot(loader.load());
            this.createMenu();

        } catch (IOException e) {
            // Do nothing, wasn't able to load the view...
        }
    }

    /**
     * Initializes the Window, disable the save button when current password field is
     * empty and username or password field is empty
     */
    @FXML
    private void initialize() {
        this.saveButton.disableProperty()
                .bind(Bindings.isEmpty(this.userNameField.textProperty())
                        .and((Bindings.isEmpty(this.passwordField.textProperty())))
                        .and((Bindings.isEmpty(this.confirmPasswordField.textProperty())))
                        .or(Bindings.isEmpty(this.currentPasswordField.textProperty())));
    }

    private String getCurrentPasswordField() {
        return this.currentPasswordField.getText().trim();
    }

    private String getUserNameField() {
        return this.userNameField.getText().trim();
    }

    private String getPasswordField() {
        return this.passwordField.getText();
    }

    private String getConfirmPasswordField() {
        return this.confirmPasswordField.getText();
    }

    /**
     * Displays an error label and a popup when an error with the password occurred
     */
    public void showErrorPassword() {
        this.passwordInfoLabel.setStyle(FX_TEXT_FILL_RED);
        this.passwordInfoLabel.setText("Error while editing password");
        Popup.showPopupPasswordRules(AlertType.WARNING);
    }

    /**
     * Displays an error label when an error with the user name occurred
     */
    public void showErrorUsername() {
        this.userNameInfoLabel.setStyle(FX_TEXT_FILL_RED);
        this.userNameInfoLabel.setText("Error while editing username");
    }

    /**
     * Hides all the labels on the screen
     */
    public void hideAllLabels() {
        if (!this.passwordInfoLabel.getText().isEmpty() || !this.userNameInfoLabel.getText().isEmpty()
                || !this.errorLabel.getText().isEmpty()) {
            this.passwordInfoLabel.setText("");
            this.userNameInfoLabel.setText("");
            this.errorLabel.setText("");
        }

    }

    /**
     * Displays an error label when the passwords don't match
     */
    public void showPasswordsDontMatchError() {
        this.passwordInfoLabel.setStyle(FX_TEXT_FILL_RED);
        this.passwordInfoLabel.setText("Password don't match !");

    }

    /**
     * Displays an error label when the current password is invalid
     */
    public void showInvalidCurrentPasswordError() {
        this.errorLabel.setStyle(FX_TEXT_FILL_RED);
        this.errorLabel.setText("Invalid current Password ");

    }

    /**
     * Displays an information popup to explain the rules on the password
     */
    public void showInfoPasswordPopup() {
        Popup.showPopupPasswordRules(AlertType.INFORMATION);
    }

    /**
     * Displays an information popup to notify the user his profile has been updated
     */
    public void showProfileEditedPopup() {
        Popup.showPopupAccountProfileEdited();
    }

    /**
     * Handles the event when the save button is pressed
     *
     * @param event
     */
    public void onSave(ActionEvent event) {
        this.editAccountController.updateAccountInformation(this.getUserNameField(), this.getCurrentPasswordField(), this.getPasswordField(),
                this.getConfirmPasswordField());
    }
}