package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.GroceryListController;
import be.ac.ulb.infof307.g02.controllers.NutritionalValuesController;
import be.ac.ulb.infof307.g02.models.GroceryList;
import be.ac.ulb.infof307.g02.models.Product;
import be.ac.ulb.infof307.g02.models.ProductAmount;
import be.ac.ulb.infof307.g02.utils.ProductAmountConverter;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.layout.VBox;
import javafx.scene.text.Text;

import java.io.IOException;
import java.util.List;

/**
 * View allowing the user to see and update his grocery lists
 */
public class GroceryListView extends ViewWithMenu implements AvailabilityChecker {

    /**
     * The fxml resource for the view
     */
    private static final String GROCERY_LIST_FXML = "groceryList.fxml";
    @FXML
    private Text title;
    @FXML
    private VBox listViewContainer;
    @FXML
    private Button createProductButton;

    private ListComponent<ProductAmount> listComponent;

    private GroceryListController groceryListController;

    public GroceryListView(GroceryListController controller, Scene scene, GroceryList groceryList,
                           List<Product> allProductsList) {
        super(controller);
        this.groceryListController = controller;

        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + GROCERY_LIST_FXML));
            loader.setController(this);
            scene.setRoot(loader.load());

            this.title.setText(this.groceryListController.getGroceryListName());
            this.listComponent = new ListComponent<>(this.listViewContainer, allProductsList, groceryList.getProductAmountList(), new ProductAmountConverter(), true, this, true, new NutritionalValuesController());
            this.createMenu();

        } catch (IOException e) {
            // Will never happen
        }
    }

    public void enableCreateProductButton() {
        this.createProductButton.setDisable(false);
    }

    /**
     * Tells the user that the grocery list has been saved successfully
     */
    public void showSuccessPopup() {
        Popup.showPopupListSaved();

    }

    /**
     * Tells the user that an error occurred while saving the grocery list
     */
    public void showErrorSavingList() {
        Popup.showPopupErrorSavingList();

    }

    /**
     * Asks the user if he wants to save the grocery list
     *
     * @return
     */
    public boolean showSaveMessageBox() {
        return Popup.showPopupConfirmSaveList();

    }

    /**
     * Checks if the listComponent has been modified
     *
     * @return
     */
    public boolean isListModified() {
        return this.listComponent.hasBeenModified();

    }

    /**
     * Adds a new product to the listComponent
     *
     * @param product
     */
    public void addNewProduct(Product product) {
        this.listComponent.addNewProduct(product);
    }

    /**
     * Cheks if some product are available in some shops
     *
     * @param product
     */
    @Override
    public void checkProductAvailability(ProductAmount product) {
        this.groceryListController.showShopsWithProduct(product);
    }

    /**
     * Checks if a list of product are available in some shops
     *
     * @param products
     */
    @Override
    public void checkListOfProductsAvailability(List<Product> products) {
        this.groceryListController.showShopsWithAllProducts();

    }

    /**
     * Event listener on the createProductButton
     *
     * @param event
     */
    @FXML
    public void onCreateProduct(ActionEvent event) {
        this.createProductButton.setDisable(true);
        this.groceryListController.createProduct();

    }

    /**
     * Event listener on the find shops button
     *
     * @param event
     */
    @FXML
    public void onFindShops(ActionEvent event) {
        this.groceryListController.showShopsWithAllProducts();
    }

    /**
     * Event listener on the save changes button
     *
     * @param event
     */
    @FXML
    public void onSaveChanges(ActionEvent event) {
        this.groceryListController.saveGroceryList(getProductAmountsList());
        this.listComponent.setHasBeenModified(false);
    }

    /**
     * Gets all the products and amounts from the listComponent
     *
     * @return
     */
    public List<ProductAmount> getProductAmountsList() {
        return this.listComponent.getItemList();
    }
}
