package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.HelpController;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.layout.StackPane;
import javafx.stage.Stage;

import java.io.IOException;

/**
 * Displays the adequate help page for the current view
 * and allows the user to change the help page being shown.
 */
public class HelpView {

    private static final String HELP_GROCERY_LIST_FXML = "helpGroceryList.fxml";
    private static final String HELP_ITEM_SELECTION_FXML = "helpSelection.fxml";
    private static final String HELP_MAP_FXML = "helpMap.fxml";
    private static final String HELP_RECIPE_FXML = "helpRecipe.fxml";
    private static final String HELP_BEST_TOUR_FXML = "helpBestTour.fxml";
    private static final String HELP_IMPORT_FXML = "helpImport.fxml";
    private static final String HELP_FILTER_FXML = "helpFilter.fxml";
    private static final String HELP_INDEX_FXML = "help.fxml";
    private static final String TITLE_WINDOW = "Help";
    private static final int WIDTH_WINDOW = 1200;
    private static final int HEIGHT_WINDOW = 800;

    /**
     * The pane in which the help pages are displayed
     */
    @FXML
    private StackPane helpPane;

    private HelpController controller;
    private Stage stage;

    public HelpView(HelpController controller, HelpPage helpPage) {
        this.controller = controller;
        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + HELP_INDEX_FXML));
            loader.setController(this);
            Parent root = loader.load();
            this.stage = new Stage();
            this.stage.setTitle(TITLE_WINDOW);
            Scene view = new Scene(root, WIDTH_WINDOW, HEIGHT_WINDOW);
            view.getStylesheets().add(Constants.CSS_FILE_PATH);
            this.stage.setScene(view);
            this.stage.setResizable(true);
            initializeHelpView(helpPage);
            this.stage.show();
            this.stage.setOnCloseRequest(event -> this.controller.onClose());

        } catch (IOException e) {
            // This exception should never happen
            // So we don't need to handle it
        }
    }

    /**
     * Sets up the user interface with a specific help page to display
     *
     * @param helpPage
     */
    private void initializeHelpView(HelpPage helpPage) {
        String fileToLoad = null;
        switch (helpPage) {
            case MAP:
                fileToLoad = HELP_MAP_FXML;
                break;

            case ITEM_SELECTION:
                fileToLoad = HELP_ITEM_SELECTION_FXML;
                break;

            case GROCERY_LIST:
                fileToLoad = HELP_GROCERY_LIST_FXML;
                break;

            case RECIPE:
                fileToLoad = HELP_RECIPE_FXML;
                break;

            case IMPORT:
                fileToLoad = HELP_IMPORT_FXML;
                break;

        }

        this.loadHelp(Constants.FXML_FOLDER_PATH + fileToLoad);
    }

    private void loadHelp(String fileToLoad) {
        Parent rightPaneContent = null;
        try {
            rightPaneContent = FXMLLoader.load(getClass().getResource(fileToLoad));
        } catch (IOException e) {
            // This exception should never happen so we don't need to handle it
        }
        this.helpPane.getChildren().setAll(rightPaneContent);
    }

    @FXML
    public void showMapHelp(ActionEvent event) {
        this.loadHelp(Constants.FXML_FOLDER_PATH + HELP_MAP_FXML);
    }

    @FXML
    public void showAllGroceryHelp(ActionEvent event) {
        this.loadHelp(Constants.FXML_FOLDER_PATH + HELP_ITEM_SELECTION_FXML);
    }

    @FXML
    public void showGroceryHelp(ActionEvent event) {
        this.loadHelp(Constants.FXML_FOLDER_PATH + HELP_GROCERY_LIST_FXML);
    }

    @FXML
    public void showRecipeHelp(ActionEvent event) {
        this.loadHelp(Constants.FXML_FOLDER_PATH + HELP_RECIPE_FXML);
    }

    @FXML
    public void showBestTourHelp(ActionEvent event) {
        this.loadHelp(Constants.FXML_FOLDER_PATH + HELP_BEST_TOUR_FXML);
    }

    @FXML
    public void showImportHelp(ActionEvent event) {
        this.loadHelp(Constants.FXML_FOLDER_PATH + HELP_IMPORT_FXML);
    }

    @FXML
    public void showFilterHelp(ActionEvent event) {
        this.loadHelp(Constants.FXML_FOLDER_PATH + HELP_FILTER_FXML);
    }


    public void close() {
        this.stage.close();
    }
}
