package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.ImportArticlesController;
import be.ac.ulb.infof307.g02.models.Article;
import be.ac.ulb.infof307.g02.models.Product;
import be.ac.ulb.infof307.g02.utils.ArticleConverter;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.layout.VBox;

import java.io.IOException;
import java.util.List;

/**
 * View allowing the user to import articles.
 */
public class ImportArticlesView extends ViewWithMenu {

    /**
     * The fxml resource for the view
     */
    private static final String IMPORT_ARTICLES_FXML = "importArticles.fxml";
    @FXML
    private VBox listViewContainer;
    @FXML
    private Button createNewProductButton;
    private ImportArticlesController importArticlesController;
    private ListComponent<Article> listComponent;


    /**
     * Constructor: Initializes the import window, disable the "help" button is the popup is already opened.
     */
    public ImportArticlesView(ImportArticlesController controller, Scene scene, List<Product> importableProducts) {
        super(controller);
        this.importArticlesController = controller;

        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + IMPORT_ARTICLES_FXML));
            loader.setController(this);
            scene.setRoot(loader.load());
            this.listComponent = new ListComponent<>(this.listViewContainer, importableProducts, new ArticleConverter());
            this.createMenu();

        } catch (IOException e) {
            // Will not happen
        }
    }

    /**
     * Event listener on the import button
     */
    public void onImport() {
        this.importArticlesController.importArticles(this.listComponent.getItemList());
    }

    /**
     * Event listener the create new product button
     */
    public void onCreateNewProduct() {
        this.createNewProductButton.setDisable(true);
        this.importArticlesController.onCreateNewProduct();

    }

    public void onSelectCSV() {
        this.importArticlesController.importFromCSV();

    }

    public void showImportCSVConsistencyError(String message) {
        Popup.showImportCSVConsistencyError(message);
    }

    public void showImportSuccessful() {
        Popup.showImportSuccessful();
    }

    public void enableCreateProduct() {
        this.createNewProductButton.setDisable(false);
    }

    public void removeProduct(Product product) {
        this.listComponent.removeProduct(product);
    }

    public void addNewProduct(Product product) {
        this.listComponent.addNewProduct(product);
    }

    public void showImportFailedForSomeProducts() {
        Popup.showImportFailedForSomeProducts();
    }
}
