package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.LoginController;
import javafx.beans.binding.Bindings;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.Label;
import javafx.scene.control.PasswordField;
import javafx.scene.control.TextField;

import java.io.IOException;

/**
 * View allowing a User to Login.
 */
public class LoginView extends ViewHandlingDBExceptions {

    /**
     * The fxml resource for the view
     */
    private static final String LOGIN_ACCOUNT_FXML = "loginAccount.fxml";
    @FXML
    private Button loginButton;
    @FXML
    private PasswordField passwordField;
    @FXML
    private TextField userNameField;
    @FXML
    private Label errorLabel;

    private LoginController controller;

    public LoginView(LoginController controller, Scene scene) {
        this.controller = controller;

        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + LOGIN_ACCOUNT_FXML));
            loader.setController(this);
            scene.setRoot(loader.load());
        } catch (IOException e) {
            // Will never happen
        }
    }

    /**
     * Initializes the Window, disable the "login" button when the username
     * field or password field is empty
     */
    @FXML
    private void initialize() {
        this.loginButton.disableProperty().bind(
                Bindings.isEmpty(this.userNameField.textProperty()).or(Bindings.isEmpty(this.passwordField.textProperty())));
    }

    /**
     * Handles the click on the "login" button. If the user doesn't
     * put the right credentials, an error label is displayed otherwise it
     * logs the user in.
     */
    // Event Listener on Button[#loginButton].onAction
    @FXML
    public void onLogin() {
        this.errorLabel.setText("");
        String userName = this.userNameField.getText().trim();
        String password = this.passwordField.getText();
        this.controller.login(userName, password);
    }

    public void showIncorrectCredentialsError() {
        this.errorLabel.setText("Incorrect credentials");
    }

    public void showInvalidCredentialsError() {
        this.errorLabel.setText("Invalid credentials");
    }

    /**
     * Handles the click on the "register" button. Displays the register
     * view
     */
    @FXML
    public void onRegister() {
        this.controller.showRegister();
    }

}
