package be.ac.ulb.infof307.g02.views;


import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.models.NutritionalValues;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.chart.PieChart;
import javafx.scene.control.Label;
import javafx.stage.Stage;

import java.io.IOException;

/**
 * Represents the nutritional value of either a single product, a recipe or a grocery list.
 */
public class NutritionalValueView {

    /**
     * The fxml resource for the view
     */
    private static final String NUTRITIONAL_VALUE_FXML = "nutritionalValue.fxml";

    private static final int HEIGHT_SCENE = 400;
    private static final int WIDTH_SCENE = 400;
    @FXML
    private PieChart nutritionalPie;
    @FXML
    private Label caloriesValue;
    @FXML
    private Label proteinsValue;
    @FXML
    private Label lipidsValue;
    @FXML
    private Label carbohydratesValue;

    private NutritionalValues nutritionalValues;


    public NutritionalValueView(NutritionalValues nutritionalValues) throws IOException {
        this.nutritionalValues = nutritionalValues;

        FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + NUTRITIONAL_VALUE_FXML));
        loader.setController(this);
        Parent root = loader.load();
        Stage stage = new Stage();
        stage.setTitle("Nutritional Value & Calories");
        Scene scene = new Scene(root, WIDTH_SCENE, HEIGHT_SCENE);
        stage.setScene(scene);
        scene.getStylesheets().add(Constants.CSS_FILE_PATH);
        stage.setAlwaysOnTop(true);
        stage.setResizable(false);
        this.setupUI();
        stage.show();
    }

    /**
     * Sets up the user interface
     */
    private void setupUI() {
        this.caloriesValue.setText(Double.toString(this.nutritionalValues.getCalories()) + " kcal");
        this.proteinsValue.setText(Double.toString(this.nutritionalValues.getProteins()) + "g");
        this.lipidsValue.setText(Double.toString(this.nutritionalValues.getLipids()) + "g");
        this.carbohydratesValue.setText(Double.toString(this.nutritionalValues.getCarbohydrates()) + "g");
        ObservableList<PieChart.Data> pieChartData = FXCollections.observableArrayList(
                new PieChart.Data("Lipids", this.nutritionalValues.getLipids()),
                new PieChart.Data("Proteins", this.nutritionalValues.getProteins()),
                new PieChart.Data("Carbohydrates", this.nutritionalValues.getCarbohydrates())
        );
        this.nutritionalPie.setData(pieChartData);
    }
}
