package be.ac.ulb.infof307.g02.views;

import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.ButtonType;
import javafx.scene.layout.Region;

import java.util.Optional;

/**
 * Allows to easily create popups.
 */
public final class Popup {

    private Popup() {
    }

    public static void showPopup(AlertType alertType, String title, String content) {
        Alert alert = new Alert(alertType);
        alert.setTitle(title);
        alert.setHeaderText(null);
        alert.setContentText(content);
        alert.getDialogPane().setMinHeight(Region.USE_PREF_SIZE);
        alert.showAndWait();
    }

    private static boolean showConfirmationPopup(String title, String content) {
        Alert alert = new Alert(AlertType.CONFIRMATION);
        alert.setTitle(title);
        alert.setHeaderText(null);
        alert.setContentText(content);
        alert.getDialogPane().setMinHeight(Region.USE_PREF_SIZE);
        ButtonType buttonTypeYes = new ButtonType("Yes");
        ButtonType buttonTypeNo = new ButtonType("No");

        alert.getButtonTypes().setAll(buttonTypeYes, buttonTypeNo);


        Optional<ButtonType> result = alert.showAndWait();
        return result.get() == buttonTypeYes;

    }

    public static void showPopupPasswordRules(AlertType alertType) {
        Popup.showPopup(alertType, "Password rules",
                "Password must be at least 8 characters long and contain at least 2 character types among 1. Numbers, 2. Lowercase, 3. Uppercase and 4. Special characters");

    }

    public static void showPopupAccountCreated() {
        Popup.showPopup(AlertType.INFORMATION, "Register Information",
                "Account Created, Please now Sign In to able to use the app");

    }

    public static void showPopupAccountProfileEdited() {
        Popup.showPopup(AlertType.INFORMATION, "Edit Profile", "Profile modified. Keep in mind the modification");
    }

    public static void showPopupListSaved() {
        Popup.showPopup(AlertType.INFORMATION, "List Saved", "Your grocery list has been saved");
    }

    public static void showPopupErrorSavingList() {
        Popup.showPopup(AlertType.WARNING, "Error while saving the list",
                "An error happened while saving the grocery list");

    }

    public static void showPopupErrorCreatingItem() {
        Popup.showPopup(AlertType.WARNING, "Error while inserting item",
                "An error happened while inserting the item");
    }

    public static void showPopupDatabaseConnection() {
        Popup.showPopup(AlertType.WARNING, "DatabaseConnection error", "An error happened while connecting to the database");

    }

    public static void showPopupDatabaseInternalError() {
        Popup.showPopup(AlertType.WARNING, "Database error", "An internal error has happened in the database");

    }

    public static boolean showPopupConfirmSaveList() {
        return Popup.showConfirmationPopup("Save changes", "The list has been modified. Do you want to save the changes ?");

    }

    public static void showPopupRecipeSaved() {
        Popup.showPopup(AlertType.INFORMATION, "Recipe Saved", "Your recipe has been saved");

    }

    public static void showPopupErrorSavingRecipe() {
        Popup.showPopup(AlertType.WARNING, "Error while saving the recipe",
                "An error happened while saving the recipe");
    }

    public static boolean showPopupConfirmSaveRecipe() {
        return Popup.showConfirmationPopup("Save changes", "The recipe has been modified. Do you want to save the changes ?");
    }

    public static void showPopupErrorGettingRecipe() {
        Popup.showPopup(AlertType.WARNING, "Database error", "This recipe has not been found");
    }

    public static boolean showPopupOverwriteConfirmation() {
        return Popup.showConfirmationPopup("Overwrite Grocery List", "There is already a GroceryList with that name. Do you want to overwrite the list?");
    }

    public static void showPopupNoTourError() {
        Popup.showPopup(AlertType.WARNING, "Best Tour", "No Best Tour found for your grocery list. Some items of the list were not available in any shops");
    }

    public static void showImportCSVConsistencyError(String message) {
        Popup.showPopup(AlertType.WARNING, "CSV Content Error", "The file is not consistent. This record is not consistent" + message);
    }

    public static void showImportSuccessful() {
        Popup.showPopup(AlertType.INFORMATION, "Import Successful", "The products are now in the shop");
    }

    public static void showUnexpectedError() {
        Popup.showPopup(AlertType.WARNING, "Unexpected error", "An unexpected error occurred");
    }


    public static void showEmptyGroceryListError() {
        Popup.showPopup(AlertType.WARNING, "Empty Grocery List", "Please select a non empty list");
    }

    public static void showImportFailedForSomeProducts() {
        Popup.showPopup(AlertType.WARNING, "Import Problems", "Some articles couldn't be imported: can't import articles which are already in the shop.");
    }
}
