package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.RegisterController;
import javafx.beans.binding.Bindings;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.Button;
import javafx.scene.control.CheckBox;
import javafx.scene.control.Label;
import javafx.scene.control.TextField;

import java.io.IOException;

/**
 * Represents the view of the register account scene.
 */
public class RegisterView extends ViewHandlingDBExceptions {

    /**
     * The fxml resource for the view
     */
    private static final String REGISTER_ACCOUNT_FXML = "registerAccount.fxml";
    @FXML
    private TextField userNameField;
    @FXML
    private TextField passwordField;
    @FXML
    private TextField confirmPasswordField;
    @FXML
    private CheckBox checkBoxToU;
    @FXML
    private Button registerButton;

    @FXML
    private Label errorLabel;

    private RegisterController controller;

    public RegisterView(RegisterController controller, Scene scene) {
        try {
            this.controller = controller;
            FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + REGISTER_ACCOUNT_FXML));
            loader.setController(this);
            scene.setRoot(loader.load());
        } catch (IOException e) {
            // Will never happen
        }
    }

    /**
     * Initialize the Window, disable the register button when username field or
     * password field when one of them is empty or checkbox of Terms of use is not
     * checked.
     */
    @FXML
    private void initialize() {
        this.registerButton.disableProperty()
                .bind(Bindings.isEmpty(this.userNameField.textProperty()).or(Bindings.isEmpty(this.passwordField.textProperty()))
                        .or(Bindings.isEmpty(this.confirmPasswordField.textProperty()))
                        .or(this.checkBoxToU.selectedProperty().not()));
    }

    public void showSuccessPopup() {
        Popup.showPopupAccountCreated();
    }

    public void showInvalidCredentialsError() {
        this.errorLabel.setText("Invalid Credentials!");
        Popup.showPopupPasswordRules(AlertType.WARNING);
    }

    public void showUserNameTakenError() {
        this.errorLabel.setText("Error username already exist !");
    }

    public void showInfoPasswordPopup() {
        Popup.showPopupPasswordRules(AlertType.INFORMATION);
    }


    /**
     * Handles the click on the Register button.
     */
    @FXML
    public void onRegister() {
        String password = this.passwordField.getText();
        String confirmPassword = this.confirmPasswordField.getText();
        if (password.equals(confirmPassword)) {
            String userName = this.userNameField.getText();
            this.controller.createUser(userName, password);
        } else {
            this.errorLabel.setText("Password don't match !");
        }

    }

    /**
     * Handles the click on the return to login button.
     */
    @FXML
    public void onReturnToLogin() {
        this.controller.goToLogin();
    }
}
