package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.SelectBestTourGroceryListController;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.control.ComboBox;
import javafx.stage.Stage;

import java.io.IOException;
import java.util.List;

/**
 * Allows the user to choose a grocery list for the BestTourFinder algorithm.
 */
public class SelectBestTourGroceryListView extends ViewHandlingDBExceptions {

    private static final String SELECT_GROCERY_LIST_FXML = "selectGroceryList.fxml";
    private static final int WIDTH_WINDOW = 350;
    private static final int HEIGHT_WINDOW = 310;
    @FXML
    private ComboBox<String> groceryListField;
    @FXML
    private Button findItineraryButton;

    private SelectBestTourGroceryListController controller;
    private Stage stage;


    public SelectBestTourGroceryListView(SelectBestTourGroceryListController controller) throws IOException {
        this.controller = controller;

        FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + SELECT_GROCERY_LIST_FXML));
        loader.setController(this);
        Parent root = loader.load();

        Scene scene = new Scene(root, WIDTH_WINDOW, HEIGHT_WINDOW);
        this.stage = new Stage();
        this.stage.setTitle("Select Grocery List");
        this.stage.setScene(scene);
        scene.getStylesheets().add(Constants.CSS_FILE_PATH);
        this.stage.setResizable(false);
        this.stage.show();
        this.stage.setOnCloseRequest(event -> this.controller.onCloseSelectGroceryListView());
        this.setupUI();
    }

    /**
     * Fills the comboBox with all the grocery list names
     */
    private void setupUI() {
        this.findItineraryButton.disableProperty().bind(this.groceryListField.valueProperty().isNull());
        List<String> list = controller.getAllGroceryList();
        ObservableList<String> items = FXCollections.observableList(list);
        this.groceryListField.getItems().clear();
        this.groceryListField.setItems(items);
    }

    /**
     * Event Listener on Button[#findItineraryButton].onAction
     */
    @FXML
    public void onFindItinerary() {
        String selectedListName = this.groceryListField.getValue();
        this.controller.onListSelected(selectedListName);

    }

    public void close() {
        this.stage.close();
    }

    public void showEmptyGroceryListError() {
        Popup.showEmptyGroceryListError();
    }
}
