package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.constants.Constants;
import be.ac.ulb.infof307.g02.controllers.ShowResultController;
import be.ac.ulb.infof307.g02.models.FindShopsResult;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.fxml.FXML;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.control.TableColumn;
import javafx.scene.control.TableView;
import javafx.scene.control.cell.PropertyValueFactory;

import java.io.IOException;

/**
 * Displays all the shops containing all the
 * products of a given grocery list or the shops containing a given product
 */
public class ShowResultView extends ViewWithMenu {

    /**
     * The fxml resource for the view
     */
    private static final String SHOW_RESULT_FXML = "showResult.fxml";
    private ObservableList<FindShopsResult> data;

    @FXML
    private TableView<FindShopsResult> table;
    @FXML
    private TableColumn shopCol;
    @FXML
    private TableColumn distCol;
    @FXML
    private TableColumn priceCol;
    @FXML
    private TableColumn scoreCol;
    private ShowResultController showResultController;

    public ShowResultView(ShowResultController controller, Scene scene) {
        super(controller);
        this.showResultController = controller;
        try {
            FXMLLoader loader = new FXMLLoader(getClass().getResource(Constants.FXML_FOLDER_PATH + SHOW_RESULT_FXML));
            loader.setController(this);
            scene.setRoot(loader.load());
            this.createMenu();

        } catch (IOException e) {
            // Will never happen
        }
    }

    /**
     * Initializes the Window. Set the cell value factory of all the cells of the
     * table. Each row of the table is represented with a FindShopsResult Object. The
     * table has 4 columns : the shop name, the distance, the price and the
     * autochef score
     */
    @FXML
    private void initialize() {
        this.data = FXCollections.observableArrayList();
        this.shopCol.setCellValueFactory(new PropertyValueFactory<FindShopsResult, String>("shopName"));
        this.distCol.setCellValueFactory(new PropertyValueFactory<FindShopsResult, String>("distance"));
        this.priceCol.setCellValueFactory(new PropertyValueFactory<FindShopsResult, String>("price"));
        this.scoreCol.setCellValueFactory(new PropertyValueFactory<FindShopsResult, String>("score"));
        this.table.setItems(this.data);
    }

    /**
     * Add a row in the table
     *
     * @param res
     */
    public void addResult(FindShopsResult res) {
        this.data.add(res);
    }

    @FXML
    public void onGoBack() {
        this.showResultController.goBackToGroceryList();
    }

}
