package be.ac.ulb.infof307.g02.views;

import be.ac.ulb.infof307.g02.controllers.ControllerWithMenu;
import javafx.fxml.FXML;
import javafx.scene.layout.HBox;

/**
 * View that can create and interact with a MenuComponent
 */
public abstract class ViewWithMenu extends ViewHandlingDBExceptions {

    @FXML
    private HBox header;

    private MenuComponent menuComponent;
    private ControllerWithMenu controllerWithMenu;

    public ViewWithMenu(ControllerWithMenu controllerWithMenu) {
        this.controllerWithMenu = controllerWithMenu;
        this.controllerWithMenu.setView(this);

    }

    protected void createMenu() {
        this.menuComponent = new MenuComponent(this, this.header);
        if (this.controllerWithMenu.isHelpOpen()) {
            this.disableHelpButton();
        }

    }

    /**
     * Shows the grocery lists
     */
    public void onMyGroceryListsClick() {
        this.controllerWithMenu.onShowAllGroceryLists();

    }

    /**
     * Shows the recipes
     */
    public void onMyRecipesClick() {
        this.controllerWithMenu.onShowAllRecipes();

    }

    /**
     * Shows the edit profile
     */
    public void onEditProfileClick() {
        this.controllerWithMenu.onShowEditProfile();

    }

    /**
     * Shows the help page
     */
    public void onHelpClick() {
        this.controllerWithMenu.onShowHelp();

    }

    /**
     * Logout
     */
    public void onLogoutClick() {
        this.controllerWithMenu.onLogout();

    }

    /**
     * Shows the map
     */
    public void onShowMapClick() {
        this.controllerWithMenu.onShowMap();
    }

    public HBox getHeader() {
        return this.header;
    }

    public void disableHelpButton() {
        this.menuComponent.disableHelpButton();
    }

    public void enableHelpButton() {
        this.menuComponent.enableHelpButton();
    }
}
