package tests.database;

import be.ac.ulb.infof307.g02.database.DatabaseConnectionSingleton;
import be.ac.ulb.infof307.g02.database.ProductDB;
import be.ac.ulb.infof307.g02.database.ShopDB;
import be.ac.ulb.infof307.g02.models.*;
import org.junit.After;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;
import tests.BaseTest;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertEquals;

public class ShopDbTest extends BaseTest {

    private ShopDB db;
    private static Schedule schedule1;
    private static Map<Product, Article> stock;

    @BeforeClass
    public static void setUpBeforeClass() throws Exception {
        stock = new HashMap<>();
        schedule1 = new Schedule();
        schedule1.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(10, 0)), Day.MONDAY);

    }

    @After
    public void tearDown() throws Exception {
        db.emptyAllTables();
    }

    @Before
    public void setUp() throws Exception {
        db = new ShopDB(DatabaseConnectionSingleton.getDatabaseConnection());
        db.emptyAllTables();

        ProductDB prodDB = new ProductDB(DatabaseConnectionSingleton.getDatabaseConnection());
        Product prod1 = new Product("banana", Product.Unit.KG, 0.3, 1.1, 23);
        Product prod2 = new Product("tomato", Product.Unit.KG, 0.2, 0.9, 3.9);
        prodDB.addProduct(prod1);
        prodDB.addProduct(prod2);

        Article art1 = new Article(prod1, 2.00F);
        Article art2 = new Article(prod2, 2.00F);

        stock.put(art1.getProduct(), art1);
        stock.put(art2.getProduct(), art2);
    }

    @Test
    public void getAllShops_Success_NoException() throws Exception {
        Shop shop = new Shop("Test1", schedule1, new Position(40.0, 50.0), stock);
        int shopID = db.addShop(shop);

        Shop shop2 = new Shop("Test2", schedule1, new Position(40.0, 60.0), stock);
        int shopID2 = db.addShop(shop2);

        List<Shop> retrievedShops = db.getAllShops();
        List<Shop> shops = new ArrayList<Shop>() {{
            add(shop);
            add(shop2);
        }};

        assertArrayEquals(shops.toArray(), retrievedShops.toArray());
        assertEquals(2, retrievedShops.size());
    }

    @Test
    public void getAllShops_NoShops_EmptyReturn() throws Exception {
        List<Shop> shops = db.getAllShops();
        assertEquals(0, shops.size());
    }

    @Test
    public void addShop_validShop_Success() throws Exception {
        Shop shop = new Shop("Test1", schedule1, new Position(40.0, 50.0), stock);
        int shopID = db.addShop(shop);

        List<Shop> shops = db.getAllShops();
        int numShopsWithID = 0;
        for (Shop retrievedShop : shops) {
            if (retrievedShop.getId() == shopID) {
                numShopsWithID++;
                assertEquals(shop, retrievedShop);
            }
        }

        assertEquals(1, numShopsWithID);
    }

    @Test
    public void deleteShop_validShop_Success() throws Exception {
        List<Shop> shopsStart = db.getAllShops();

        Shop shop = new Shop("Test1", schedule1, new Position(40.0, 50.0), stock);
        int shopID = db.addShop(shop);

        List<Shop> shopsMiddle = db.getAllShops();
        assertEquals(shopsMiddle.size(), shopsStart.size() + 1);
        db.deleteShop(shopID);

        List<Shop> shopsEnd = db.getAllShops();
        assertEquals(shopsEnd.size(), shopsStart.size());
    }

    @Test
    public void empty_notEmpty_empty() throws Exception {
        Shop shop = new Shop("Test1", schedule1, new Position(40.0, 50.0), stock);
        db.addShop(shop);
        db.emptyAllTables();
        List<Shop> shops = db.getAllShops();
        assertEquals(0, shops.size());
    }

}
