package tests.database;

import be.ac.ulb.infof307.g02.database.DatabaseConnectionSingleton;
import be.ac.ulb.infof307.g02.database.UserDB;
import be.ac.ulb.infof307.g02.exceptions.database.DatabaseException;
import be.ac.ulb.infof307.g02.exceptions.database.NoSuchUserFoundException;
import be.ac.ulb.infof307.g02.exceptions.database.UserNameTakenException;
import be.ac.ulb.infof307.g02.exceptions.model.InvalidPasswordException;
import be.ac.ulb.infof307.g02.exceptions.model.UserCreationException;
import be.ac.ulb.infof307.g02.models.User;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import tests.BaseTest;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public class UserDBTest extends BaseTest {

    private UserDB db;

    @After
    public void tearDownAfterClass() throws Exception {
        db.emptyAllTables();
    }

    @Before
    public void setup() throws Exception {
        db = new UserDB(DatabaseConnectionSingleton.getDatabaseConnection());
        db.emptyAllTables();
    }

    @Test(expected = NoSuchUserFoundException.class)
    public void getUser_EmptyDB_NoUsers() throws DatabaseException, NoSuchUserFoundException {
        db.getUserByName("Bob L'eponge");
    }

    @Test
    public void getUser_AddedBob_BobExists()
            throws UserCreationException, UserNameTakenException, DatabaseException, NoSuchUserFoundException {
        User user = new User("Bob", "aaaaaaXXX");
        db.addUser(user);
        User retrievedUser = db.getUserByName(user.getUserName());

        assertEquals(user.getUserName(), retrievedUser.getUserName());
        assertEquals(user.getHashedPassword(), retrievedUser.getHashedPassword());
    }

    @Test
    public void updateUserName_NewNameJames_UserNameUpdated()
            throws UserCreationException, UserNameTakenException, DatabaseException, NoSuchUserFoundException {
        User user = new User("Bob", "aaaaaaXXX");
        db.addUser(user);

        user.setUserName("James");
        db.updateUserName("Bob", "James");
        User retrievedUser = db.getUserByName(user.getUserName());

        assertEquals(user.getUserName(), retrievedUser.getUserName());
        assertEquals(user.getHashedPassword(), retrievedUser.getHashedPassword());
    }

    @Test(expected = NoSuchUserFoundException.class)
    public void updateUserName_NewNameJames_UserBobGone()
            throws UserNameTakenException, UserCreationException, DatabaseException, NoSuchUserFoundException {
        User user = new User("Bob", "Bob123456789");
        db.addUser(user);

        db.updateUserName("Bob", "James");
        User retrievedUser = db.getUserByName("Bob");
    }

    @Test
    public void updatePassword_NewPassaaaaaaXXX_PasswordUpdated() throws UserCreationException, UserNameTakenException,
            DatabaseException, InvalidPasswordException, NoSuchUserFoundException {
        User user = new User("Bob", "Bob123456789");
        db.addUser(user);
        User retrievedUser = db.getUserByName(user.getUserName());
        retrievedUser.setPassword("aaaaaaXXX");
        db.updatePassword("Bob", retrievedUser.getHashedPassword());
        assertTrue(db.getUserByName(user.getUserName()).passwordMatches("aaaaaaXXX"));
    }
}
