package tests.models;

import be.ac.ulb.infof307.g02.exceptions.model.InvalidProductAmountException;
import be.ac.ulb.infof307.g02.models.GroceryList;
import be.ac.ulb.infof307.g02.models.Product;
import be.ac.ulb.infof307.g02.models.ProductAmount;
import org.junit.Test;
import tests.BaseTest;

import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class GroceryListTest extends BaseTest {

    @Test
    public void constructor_ValidValues_CorrectCreation() {
        List<ProductAmount> productList = new ArrayList<>();
        ProductAmount item = new ProductAmount(new Product("Banana", Product.Unit.KG, 0.3, 1.1, 23), 10.5);
        productList.add(item);
        String groceryListName = "Fruit";
        GroceryList groceryListModel = new GroceryList(groceryListName, productList);
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_EmptyListName_ThrowsException() {
        List<ProductAmount> productList = new ArrayList<>();
        ProductAmount item = new ProductAmount(new Product("Banana", Product.Unit.KG, 0.3, 1.1, 23), 10.5);
        productList.add(item);
        String groceryListName = "";
        GroceryList groceryListModel = new GroceryList(groceryListName, productList);
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_GroceryListNameOnlyWhitespace_ThrowsException() {
        List<ProductAmount> productList = new ArrayList<>();
        ProductAmount item = new ProductAmount(new Product("Banana", Product.Unit.KG, 0.3, 1.1, 23), 10.5);
        productList.add(item);
        String groceryListName = "             ";
        GroceryList groceryListModel = new GroceryList(groceryListName, productList);
    }

    @Test
    public void addProduct_ValidInsertion_True() {
        String groceryListName = "Fruit";
        List<ProductAmount> productList = new ArrayList<>();
        ProductAmount item = new ProductAmount(new Product("Banana", Product.Unit.KG, 0.3, 1.1, 23), 10.5);
        productList.add(item);
        GroceryList groceryList = new GroceryList(groceryListName, productList);
        ProductAmount newItem = new ProductAmount(new Product("Orange", Product.Unit.UNIT, 0.1, 0.9, 12), 10.5);
        groceryList.addProductOrIncreaseAmount(newItem);
        assertTrue(groceryList.getProductAmountList().contains(item));
    }

    @Test(expected = InvalidProductAmountException.class)
    public void addProduct_NotValidInsertion() throws InvalidProductAmountException {
        String groceryListName = "Fruit";
        List<ProductAmount> productList = new ArrayList<>();
        ProductAmount item = new ProductAmount(new Product("Banana", Product.Unit.KG, 0.3, 1.1, 23), 10.5);
        productList.add(item);
        GroceryList groceryList = new GroceryList(groceryListName, productList);
        groceryList.addProductAmount(item);
    }

    @Test
    public void delProduct_ValidDelete_True() {
        String groceryListName = "Fruit";
        List<ProductAmount> productList = new ArrayList<>();
        ProductAmount item = new ProductAmount(new Product("Banana", Product.Unit.KG, 0.3, 1.1, 23), 10.5);
        productList.add(item);
        GroceryList groceryList = new GroceryList(groceryListName, productList);
        groceryList.deleteItem(item);
        assertFalse(groceryList.getProductAmountList().contains(item));
    }

}
