package tests.models;

import be.ac.ulb.infof307.g02.models.NutritionalValues;
import be.ac.ulb.infof307.g02.models.NutritionalValuesCalculator;
import be.ac.ulb.infof307.g02.models.Product;
import be.ac.ulb.infof307.g02.models.ProductAmount;
import org.junit.Test;
import tests.BaseTest;
import tests.TestUtils;

import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertEquals;

public class NutritionalValuesCalculatorTest extends BaseTest {

    @Test
    public void computeNutritionalValues_Banana_Success() {
        double lipidsPer100g = 0.3;
        double proteinsPer100g = 1.1;
        double carbohydratesPer100g = 23.0;
        double bananaCalories = 99.1;

        Product banana = new Product("banana", Product.Unit.KG, lipidsPer100g, proteinsPer100g, carbohydratesPer100g);
        ProductAmount productAmount = new ProductAmount(banana, 3);

        NutritionalValues nutritionalValues = NutritionalValuesCalculator.computeNutritionalValues(productAmount);
        TestUtils.assertDoubleEquals(30 * lipidsPer100g, nutritionalValues.getLipids());
        TestUtils.assertDoubleEquals(30 * proteinsPer100g, nutritionalValues.getProteins());
        TestUtils.assertDoubleEquals(30 * carbohydratesPer100g, nutritionalValues.getCarbohydrates());
        assertEquals(30 * bananaCalories, nutritionalValues.getCalories(), 1);
    }

    @Test
    public void computeAllNutritionalValues_BananaAndTomato_Success() {
        double bananaLipidsPer100g = 0.3;
        double bananaProteinsPer100g = 1.1;
        double bananaCarbohydratesPer100g = 23.0;
        double bananaCalories = 99.1;

        Product banana = new Product("banana", Product.Unit.KG, bananaLipidsPer100g, bananaProteinsPer100g, bananaCarbohydratesPer100g);
        ProductAmount bananaProductAmount = new ProductAmount(banana, 3);


        double tomatoLipidsPer100g = 0.2;
        double tomatoProteinsPer100g = 0.9;
        double tomatoCarbohydratesPer100g = 3.9;
        Product tomato = new Product("tomato", Product.Unit.KG, tomatoLipidsPer100g, tomatoProteinsPer100g, tomatoCarbohydratesPer100g);
        double tomatoCaloriesPer100g = 21.0;


        ProductAmount tomatoProductAmount = new ProductAmount(tomato, 3);

        List<ProductAmount> productAmountList = new ArrayList<>();
        productAmountList.add(bananaProductAmount);
        productAmountList.add(tomatoProductAmount);

        NutritionalValues nutritionalValues = NutritionalValuesCalculator.computeAllNutritionalValues(productAmountList);
        TestUtils.assertDoubleEquals(30 * (bananaLipidsPer100g + tomatoLipidsPer100g), nutritionalValues.getLipids());
        TestUtils.assertDoubleEquals(30 * (bananaProteinsPer100g + tomatoProteinsPer100g), nutritionalValues.getProteins());
        TestUtils.assertDoubleEquals(30 * (bananaCarbohydratesPer100g + tomatoCarbohydratesPer100g), nutritionalValues.getCarbohydrates());
        assertEquals(30 * (bananaCalories + tomatoCaloriesPer100g), nutritionalValues.getCalories(), 1);
    }
}