package tests.models;

import be.ac.ulb.infof307.g02.models.Position;
import org.junit.Test;
import tests.BaseTest;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

public class PositionTest extends BaseTest {

    @Test
    public void constructor_validCoordinates_Success() {
        Position pos = new Position(50, 50);
        pos = new Position(50, 180);
        pos = new Position(90, 50);
        pos = new Position(0, 50);
        pos = new Position(50, 0);
        pos = new Position(-90, 0);
        pos = new Position(0, -180);
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_LongTooBig_ThrowsException() {
        Position pos = new Position(0, 180.00001);
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_LatTooBig_ThrowsException() {
        Position pos = new Position(90.001, 0);
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_LongTooSmall_ThrowsException() {
        Position pos = new Position(0, -180.00001);
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_LatTooSmall_ThrowsException() {
        Position pos = new Position(-90.001, 0);
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_LatLongTooBig_ThrowsException() {
        Position pos = new Position(200, 300);
    }

    @Test
    public void areCoordinatesValid_validCoordinates_ReturnTrue() {
        assertTrue(Position.areCoordinatesValid(50, 50));
        assertTrue(Position.areCoordinatesValid(50, 180));
        assertTrue(Position.areCoordinatesValid(90, 50));
        assertTrue(Position.areCoordinatesValid(0, 50));
        assertTrue(Position.areCoordinatesValid(50, 0));
        assertTrue(Position.areCoordinatesValid(-90, 0));
        assertTrue(Position.areCoordinatesValid(0, -180));
    }

    @Test
    public void areCoordinatesValid_invalidCoordinates_ReturnFalse() {
        assertFalse(Position.areCoordinatesValid(0, 180.00001));
        assertFalse(Position.areCoordinatesValid(90.001, 0));
        assertFalse(Position.areCoordinatesValid(0, -180.00001));
        assertFalse(Position.areCoordinatesValid(-90.001, 0));
        assertFalse(Position.areCoordinatesValid(200, 300));
    }

}
