package tests.models;

import be.ac.ulb.infof307.g02.models.*;
import org.junit.BeforeClass;
import org.junit.Test;
import tests.BaseTest;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static junit.framework.TestCase.assertTrue;

public class ShopFiltererTest extends BaseTest {

    private static Shop carrefour;
    private static Shop colruyt;
    private static Shop aldi;
    private static Shop floShop;
    private static List<Shop> shops;

    @BeforeClass
    public static void setUpBeforeClass() {

        Product prod1 = new Product("banana", Product.Unit.KG, 0.3, 1.1, 23);
        Product prod2 = new Product("tomato", Product.Unit.KG, 0.2, 0.9, 3.9);
        Product prod3 = new Product("salt", Product.Unit.KG, 0, 0, 0);
        Product prod4 = new Product("milk", Product.Unit.LITER, 1, 3.4, 5);


        Position pos1 = new Position(50.849319, 4.356506);
        Position pos2 = new Position(50.849319, 4.357506);
        Position pos3 = new Position(50.849319, 4.355506);
        Position pos4 = new Position(50.8444, 4.3559);
        Schedule schedule = new Schedule();
        schedule.addTimeSlot(new TimeSlot(new Time(8, 0), new Time(12, 0)), Day.MONDAY);
        schedule.addTimeSlot(new TimeSlot(new Time(14, 0), new Time(18, 0)), Day.MONDAY);

        Article art1Shop1 = new Article(prod1, 10.00F);
        Article art1Shop2 = new Article(prod1, 2.00F);
        Article art2 = new Article(prod2, 2.00F);
        Article art3 = new Article(prod3, 2.00F);
        Article art4 = new Article(prod4, 6.66F);

        Map<Product, Article> stock1 = new HashMap<>();
        stock1.put(art1Shop1.getProduct(), art1Shop1);
        stock1.put(art2.getProduct(), art2);
        stock1.put(art3.getProduct(), art3);

        Map<Product, Article> stock2 = new HashMap<>();
        stock2.put(art1Shop2.getProduct(), art1Shop2);
        stock2.put(art2.getProduct(), art2);
        stock2.put(art3.getProduct(), art3);

        Map<Product, Article> stock3 = new HashMap<>();
        stock3.put(art4.getProduct(), art4);

        carrefour = new Shop(1, "Carrefour Market", schedule, pos1, stock1);
        colruyt = new Shop(1, "Colruyt", schedule, pos2, stock2);
        aldi = new Shop(1, "Aldi", schedule, pos3, stock1);
        floShop = new Shop(1, "Flo's Shop", schedule, pos4, stock3);

        shops = new ArrayList<Shop>() {{
            add(carrefour);
            add(colruyt);
            add(aldi);
            add(floShop);
        }};
    }

    @Test
    public void filterShops_onNameAldi_keepOnlyAldi() {
        ShopFilterer filterer = new ShopFilterer(shops, new Position(50.799076, 4.357487));
        List<Shop> result = filterer.filterShops(new FilterData("Aldi", 0,
                new ArrayList<>(), null, new ArrayList<>()));

        assertTrue(result.size() == 1 && result.contains(aldi));

    }

    @Test
    public void filterShops_onDistaneOneKM_removeAll() {
        ShopFilterer filterer = new ShopFilterer(shops, new Position(50.799076, 4.357487));
        List<Shop> result = filterer.filterShops(new FilterData("", 1,
                new ArrayList<>(), null, new ArrayList<>()));

        assertTrue(result.isEmpty());

    }

    @Test
    public void filterShops_onOpenDayMonday_keepAll() {
        ShopFilterer filterer = new ShopFilterer(shops, new Position(50.799076, 4.357487));
        List<Shop> result = filterer.filterShops(new FilterData("", 0,
                new ArrayList<Day>() {{
                    add(Day.MONDAY);
                }}, null, new ArrayList<>()));

        assertTrue(result.size() == shops.size());

    }

    @Test
    public void filterShops_onOpenHour13H49_removeAll() {
        ShopFilterer filterer = new ShopFilterer(shops, new Position(50.799076, 4.357487));
        List<Shop> result = filterer.filterShops(new FilterData("", 0, new ArrayList<>(),
                new Time(13, 49), new ArrayList<>()));

        assertTrue(result.size() == 0);

    }

    @Test
    public void filterShops_onStockMilk_keepFlo() {
        ShopFilterer filterer = new ShopFilterer(shops, new Position(50.799076, 4.357487));
        List<Shop> result = filterer.filterShops(new FilterData("", 0, new ArrayList<>(),
                null, new ArrayList<Product>() {{
            add(new Product("milk", Product.Unit.LITER, 1, 3.4, 5));
        }}));

        assertTrue(result.size() == 1 && result.contains(floShop));

    }

    @Test
    public void filterShops_onAllFields_keepColruyt() {
        ShopFilterer filterer = new ShopFilterer(shops, new Position(50.799076, 4.357487));
        List<Shop> result = filterer.filterShops(new FilterData("Colruyt", 50,
                new ArrayList<Day>() {{
                    add(Day.MONDAY);
                }}, new Time(10, 30),
                new ArrayList<Product>() {{
                    add(new Product("banana", Product.Unit.KG, 0.3, 1.1, 23));
                }}));

        assertTrue(result.size() == 1 && result.contains(colruyt));

    }
}
