package tests.models;

import be.ac.ulb.infof307.g02.models.Time;
import be.ac.ulb.infof307.g02.models.TimeSlot;
import org.junit.Test;
import tests.BaseTest;

import static junit.framework.TestCase.assertTrue;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;

public class TimeSlotTest extends BaseTest {

    @Test
    public void constructor_validValues_correctCreation() {
        new TimeSlot(new Time(8, 0), new Time(10, 0));
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_openHourAfterCloseHour_throwException() {
        new TimeSlot(new Time(10, 0), new Time(8, 0));
    }

    @Test(expected = IllegalArgumentException.class)
    public void constructor_openMinAfterCloseMin_throwException() {
        new TimeSlot(new Time(8, 30), new Time(8, 0));
    }

    @Test
    public void toStringRepresentation_singleDigitTimes_validString() {
        TimeSlot timeSlot = new TimeSlot(new Time(8, 1), new Time(9, 2));
        assertEquals("08:01 - 09:02", timeSlot.toString());
    }

    @Test
    public void toStringRepresentation_doubleDigitTimes_validString() {
        TimeSlot timeSlot = new TimeSlot(new Time(12, 15), new Time(15, 45));
        assertEquals("12:15 - 15:45", timeSlot.toString());
    }

    @Test
    public void isTimeOverlapping_10h00_11h00_10h30_11h15_True() {
        TimeSlot timeSlot1 = new TimeSlot(new Time(10, 0), new Time(11, 0));
        TimeSlot timeSlot2 = new TimeSlot(new Time(10, 30), new Time(11, 15));
        assertTrue(timeSlot2.isTimeSlotOverlapping(timeSlot1));
    }

    @Test
    public void contains_10h00_8h00_12h00_True() {
        TimeSlot timeSlot = new TimeSlot(new Time(8, 0), new Time(10, 0));
        Time time = new Time(9, 42);
        assertTrue(timeSlot.contains(time));
    }

    @Test
    public void contains_13h00_8h00_12h00_False() {
        TimeSlot timeSlot = new TimeSlot(new Time(8, 0), new Time(10, 0));
        Time time = new Time(13, 0);
        assertFalse(timeSlot.contains(time));
    }
}
